@@ -120,11 +120,10 @@ for a different domain.
 
 (*) The RID is typically the last integer of a user or group SID which follows
 the domain SID. E.g. if the domain SID is S-1-5-21-123-456-789 and a user from
-this domain has the SID S-1-5-21-123-456-789-1010 then 1010 id the RID of the
+this domain has the SID S-1-5-21-123-456-789-1010 then 1010 is the RID of the
 user. RIDs are unique in a domain, 32bit values and are used for users and
 groups.
 
-=======
 WARNING:
 
 DNA plugin in 389-ds will allocate IDs based on the ranges configured for the
@@ -135,7 +134,6 @@ Manual configuration change has to be done in the DNA plugin configuration for
 the new local range. Specifically, The dnaNextRange attribute of 'cn=Posix
 IDs,cn=Distributed Numeric Assignment Plugin,cn=plugins,cn=config' has to be
 modified to match the new range.
-=======
 """)
 
 register = Registry()
@@ -208,18 +206,16 @@ Add new ID range.
 
     must be given to add a new range for a trusted AD domain.
 
-=======
-WARNING:
+    WARNING:
 
-DNA plugin in 389-ds will allocate IDs based on the ranges configured for the
-local domain. Currently the DNA plugin *cannot* be reconfigured itself based
-on the local ranges set via this family of commands.
+    DNA plugin in 389-ds will allocate IDs based on the ranges configured for the
+    local domain. Currently the DNA plugin *cannot* be reconfigured itself based
+    on the local ranges set via this family of commands.
 
-Manual configuration change has to be done in the DNA plugin configuration for
-the new local range. Specifically, The dnaNextRange attribute of 'cn=Posix
-IDs,cn=Distributed Numeric Assignment Plugin,cn=plugins,cn=config' has to be
-modified to match the new range.
-=======
+    Manual configuration change has to be done in the DNA plugin configuration for
+    the new local range. Specifically, The dnaNextRange attribute of 'cn=Posix
+    IDs,cn=Distributed Numeric Assignment Plugin,cn=plugins,cn=config' has to be
+    modified to match the new range.
     """)
 
     takes_args = (
@@ -414,13 +410,13 @@ class idrange_find(Method):
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
+            doc=_(u'Time limit of search in seconds'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
+            doc=_(u'Maximum number of entries returned'),
         ),
         parameters.Flag(
             'all',
@@ -469,22 +465,7 @@ class idrange_find(Method):
 
 @register()
 class idrange_mod(Method):
-    __doc__ = _("""
-Modify ID range.
-
-=======
-WARNING:
-
-DNA plugin in 389-ds will allocate IDs based on the ranges configured for the
-local domain. Currently the DNA plugin *cannot* be reconfigured itself based
-on the local ranges set via this family of commands.
-
-Manual configuration change has to be done in the DNA plugin configuration for
-the new local range. Specifically, The dnaNextRange attribute of 'cn=Posix
-IDs,cn=Distributed Numeric Assignment Plugin,cn=plugins,cn=config' has to be
-modified to match the new range.
-=======
-    """)
+    __doc__ = _("Modify ID range.")
 
     takes_args = (
         parameters.Str(
