@@ -19,7 +19,7 @@ if six.PY3:
 __doc__ = _("""
 Simulate use of Host-based access controls
 
-HBAC rules control who can access what services on what hosts and from where.
+HBAC rules control who can access what services on what hosts.
 You can use HBAC to control which users or groups can access a service,
 or group of services, on a target host.
 
@@ -32,7 +32,7 @@ having access to the production environment.
 
  ipa hbactest --user= --host= --service=
               [--rules=rules-list] [--nodetail] [--enabled] [--disabled]
-              [--srchost= ] [--sizelimit= ]
+              [--sizelimit= ]
 
  --user, --host, and --service are mandatory, others are optional.
 
@@ -52,8 +52,6 @@ having access to the production environment.
  By default there is a IPA-wide limit to number of entries fetched, you can change it
  with --sizelimit option.
 
- If --srchost is specified, it will be ignored. It is left because of compatibility reasons only.
-
 EXAMPLES:
 
     1. Use all enabled HBAC rules in IPA database to simulate:
@@ -61,10 +59,10 @@ EXAMPLES:
     --------------------
     Access granted: True
     --------------------
-      notmatched: my-second-rule
-      notmatched: my-third-rule
-      notmatched: myrule
-      matched: allow_all
+      Not matched rules: my-second-rule
+      Not matched rules: my-third-rule
+      Not matched rules: myrule
+      Matched rules: allow_all
 
     2. Disable detailed summary of how rules were applied:
     $ ipa hbactest --user=a1a --host=bar --service=sshd --nodetail
@@ -73,49 +71,122 @@ EXAMPLES:
     --------------------
 
     3. Test explicitly specified HBAC rules:
-    $ ipa hbactest --user=a1a --host=bar --service=sshd           --rules=my-second-rule,myrule
+    $ ipa hbactest --user=a1a --host=bar --service=sshd \
+          --rules=myrule --rules=my-second-rule
     ---------------------
     Access granted: False
     ---------------------
-      notmatched: my-second-rule
-      notmatched: myrule
+      Not matched rules: my-second-rule
+      Not matched rules: myrule
 
     4. Use all enabled HBAC rules in IPA database + explicitly specified rules:
-    $ ipa hbactest --user=a1a --host=bar --service=sshd           --rules=my-second-rule,myrule --enabled
+    $ ipa hbactest --user=a1a --host=bar --service=sshd \
+          --rules=myrule --rules=my-second-rule --enabled
     --------------------
     Access granted: True
     --------------------
-      notmatched: my-second-rule
-      notmatched: my-third-rule
-      notmatched: myrule
-      matched: allow_all
+      Not matched rules: my-second-rule
+      Not matched rules: my-third-rule
+      Not matched rules: myrule
+      Matched rules: allow_all
 
     5. Test all disabled HBAC rules in IPA database:
     $ ipa hbactest --user=a1a --host=bar --service=sshd --disabled
     ---------------------
     Access granted: False
     ---------------------
-      notmatched: new-rule
+      Not matched rules: new-rule
 
     6. Test all disabled HBAC rules in IPA database + explicitly specified rules:
-    $ ipa hbactest --user=a1a --host=bar --service=sshd           --rules=my-second-rule,myrule --disabled
+    $ ipa hbactest --user=a1a --host=bar --service=sshd \
+          --rules=myrule --rules=my-second-rule --disabled
     ---------------------
     Access granted: False
     ---------------------
-      notmatched: my-second-rule
-      notmatched: my-third-rule
-      notmatched: myrule
+      Not matched rules: my-second-rule
+      Not matched rules: my-third-rule
+      Not matched rules: myrule
 
     7. Test all (enabled and disabled) HBAC rules in IPA database:
-    $ ipa hbactest --user=a1a --host=bar --service=sshd           --enabled --disabled
+    $ ipa hbactest --user=a1a --host=bar --service=sshd \
+          --enabled --disabled
     --------------------
     Access granted: True
     --------------------
-      notmatched: my-second-rule
-      notmatched: my-third-rule
-      notmatched: myrule
-      notmatched: new-rule
-      matched: allow_all
+      Not matched rules: my-second-rule
+      Not matched rules: my-third-rule
+      Not matched rules: myrule
+      Not matched rules: new-rule
+      Matched rules: allow_all
+
+
+HBACTEST AND TRUSTED DOMAINS
+
+When an external trusted domain is configured in IPA, HBAC rules are also applied
+on users accessing IPA resources from the trusted domain. Trusted domain users and
+groups (and their SIDs) can be then assigned to external groups which can be
+members of POSIX groups in IPA which can be used in HBAC rules and thus allowing
+access to resources protected by the HBAC system.
+
+hbactest plugin is capable of testing access for both local IPA users and users
+from the trusted domains, either by a fully qualified user name or by user SID.
+Such user names need to have a trusted domain specified as a short name
+(DOMAIN\Administrator) or with a user principal name (UPN), Administrator@ad.test.
+
+Please note that hbactest executed with a trusted domain user as --user parameter
+can be only run by members of "trust admins" group.
+
+EXAMPLES:
+
+    1. Test if a user from a trusted domain specified by its shortname matches any
+       rule:
+
+    $ ipa hbactest --user 'DOMAIN\Administrator' --host `hostname` --service sshd
+    --------------------
+    Access granted: True
+    --------------------
+      Matched rules: allow_all
+      Matched rules: can_login
+
+    2. Test if a user from a trusted domain specified by its domain name matches
+       any rule:
+
+    $ ipa hbactest --user 'Administrator@domain.com' --host `hostname` --service sshd
+    --------------------
+    Access granted: True
+    --------------------
+      Matched rules: allow_all
+      Matched rules: can_login
+
+    3. Test if a user from a trusted domain specified by its SID matches any rule:
+
+    $ ipa hbactest --user S-1-5-21-3035198329-144811719-1378114514-500 \
+            --host `hostname` --service sshd
+    --------------------
+    Access granted: True
+    --------------------
+      Matched rules: allow_all
+      Matched rules: can_login
+
+    4. Test if other user from a trusted domain specified by its SID matches any rule:
+
+    $ ipa hbactest --user S-1-5-21-3035198329-144811719-1378114514-1203 \
+            --host `hostname` --service sshd
+    --------------------
+    Access granted: True
+    --------------------
+      Matched rules: allow_all
+      Not matched rules: can_login
+
+   5. Test if other user from a trusted domain specified by its shortname matches
+       any rule:
+
+    $ ipa hbactest --user 'DOMAIN\Otheruser' --host `hostname` --service sshd
+    --------------------
+    Access granted: True
+    --------------------
+      Matched rules: allow_all
+      Not matched rules: can_login
 """)
 
 register = Registry()
@@ -133,8 +204,8 @@ class hbactest(Command):
         parameters.Str(
             'sourcehost',
             required=False,
-            cli_name='srchost',
-            label=_(u'Source host'),
+            deprecated=True,
+            exclude=('cli', 'webui'),
         ),
         parameters.Str(
             'targethost',
