@@ -158,6 +158,18 @@ class permission(Object):
             label=_(u'Target DN'),
             doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
         ),
+        parameters.DNParam(
+            'ipapermtargetto',
+            required=False,
+            label=_(u'Target DN subtree'),
+            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
+        ),
+        parameters.DNParam(
+            'ipapermtargetfrom',
+            required=False,
+            label=_(u'Origin DN subtree'),
+            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+        ),
         parameters.Str(
             'memberof',
             required=False,
@@ -275,6 +287,20 @@ class permission_add(Method):
             label=_(u'Target DN'),
             doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
         ),
+        parameters.DNParam(
+            'ipapermtargetto',
+            required=False,
+            cli_name='targetto',
+            label=_(u'Target DN subtree'),
+            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
+        ),
+        parameters.DNParam(
+            'ipapermtargetfrom',
+            required=False,
+            cli_name='targetfrom',
+            label=_(u'Origin DN subtree'),
+            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+        ),
         parameters.Str(
             'memberof',
             required=False,
@@ -629,6 +655,20 @@ class permission_find(Method):
             label=_(u'Target DN'),
             doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
         ),
+        parameters.DNParam(
+            'ipapermtargetto',
+            required=False,
+            cli_name='targetto',
+            label=_(u'Target DN subtree'),
+            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
+        ),
+        parameters.DNParam(
+            'ipapermtargetfrom',
+            required=False,
+            cli_name='targetfrom',
+            label=_(u'Origin DN subtree'),
+            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+        ),
         parameters.Str(
             'memberof',
             required=False,
@@ -673,13 +713,13 @@ class permission_find(Method):
             'timelimit',
             required=False,
             label=_(u'Time Limit'),
-            doc=_(u'Time limit of search in seconds'),
+            doc=_(u'Time limit of search in seconds (0 is unlimited)'),
         ),
         parameters.Int(
             'sizelimit',
             required=False,
             label=_(u'Size Limit'),
-            doc=_(u'Maximum number of entries returned'),
+            doc=_(u'Maximum number of entries returned (0 is unlimited)'),
         ),
         parameters.Flag(
             'all',
@@ -814,6 +854,20 @@ class permission_mod(Method):
             label=_(u'Target DN'),
             doc=_(u'Optional DN to apply the permission to (must be in the subtree, but may not yet exist)'),
         ),
+        parameters.DNParam(
+            'ipapermtargetto',
+            required=False,
+            cli_name='targetto',
+            label=_(u'Target DN subtree'),
+            doc=_(u'Optional DN subtree where an entry can be moved to (must be in the subtree, but may not yet exist)'),
+        ),
+        parameters.DNParam(
+            'ipapermtargetfrom',
+            required=False,
+            cli_name='targetfrom',
+            label=_(u'Origin DN subtree'),
+            doc=_(u'Optional DN subtree from where an entry can be moved (must be in the subtree, but may not yet exist)'),
+        ),
         parameters.Str(
             'memberof',
             required=False,
