@@ -130,6 +130,13 @@ from ipapython.dn import DN
 from ipapython.dnsutil import DNSName
 
 
+MAX_UINT32 = (1 << 32) - 1
+# JavaScript Number.MAX_SAFE_INTEGER / Number.MIN_SAFE_INTEGER
+# JSON cannot safely encode values outside this range as regular number
+MAX_SAFE_INTEGER = (2**53) - 1
+MIN_SAFE_INTEGER = -MAX_SAFE_INTEGER
+
+
 def _is_null(value):
     if value:
         return False
@@ -1093,6 +1100,12 @@ class Int(Number):
     allowed_types = (int,)
     type_error = _('must be an integer')
 
+    MININT = MININT
+    MAXINT = MAXINT
+    MAX_UINT32 = MAX_UINT32
+    MAX_SAFE_INTEGER = MAX_SAFE_INTEGER
+    MIN_SAFE_INTEGER = MIN_SAFE_INTEGER
+
     kwargs = Param.kwargs + (
         ('minvalue', int, int(MININT)),
         ('maxvalue', int, int(MAXINT)),
@@ -1124,6 +1137,16 @@ class Int(Number):
                 '%s: minvalue > maxvalue (minvalue=%r, maxvalue=%r)' % (
                     self.nice, self.minvalue, self.maxvalue)
             )
+        if self.minvalue < self.MIN_SAFE_INTEGER:
+            raise ValueError(
+                f"minvalue {self.minvalue} outside range of safe JSON "
+                f"integer limit {self.MIN_SAFE_INTEGER}"
+            )
+        if self.maxvalue > self.MAX_SAFE_INTEGER:
+            raise ValueError(
+                f"maxvalue {self.maxvalue} outside range of safe JSON "
+                f"integer limit {self.MAX_SAFE_INTEGER}"
+            )
 
     def _convert_scalar(self, value, index=None):
         """
@@ -1646,6 +1669,11 @@ class Password(Str):
     A parameter for passwords (stored in the ``unicode`` type).
     """
 
+    kwargs = Data.kwargs + (
+        ('pattern', (str,), None),
+        ('noextrawhitespace', bool, False),
+    )
+
     password = True
 
     def _convert_scalar(self, value, index=None):
@@ -1808,7 +1836,7 @@ class DateTime(Param):
     def _convert_scalar(self, value, index=None):
         if isinstance(value, str):
             if value == u'now':
-                time = datetime.datetime.utcnow()
+                time = datetime.datetime.now(tz=datetime.timezone.utc)
                 return time
             else:
                 for date_format in self.accepted_formats:
@@ -2018,6 +2046,10 @@ class DNParam(Param):
         if type(value) in self.allowed_types:
             return value
 
+        if type(value) in (tuple, list):
+            raise ConversionError(name=self.name,
+                                  error=ugettext(self.scalar_error))
+
         try:
             dn = DN(value)
         except Exception as e:
@@ -2222,3 +2254,47 @@ def create_signature(command):
     )
 
     return signature
+
+
+class SerialNumber(Str):
+    """Certificate serial number parameter type
+    """
+
+    type = str
+    allowed_types = (str,)
+
+    # FIXME: currently unused, perhaps drop it
+    MAX_VALUE = 340282366920938463463374607431768211456  # 2^128
+
+    kwargs = Param.kwargs + (
+        ('minlength', int, 1),
+        ('maxlength', int, 40),  # Up to 128-bit values
+        ('length', int, None),
+    )
+
+    def _validate_scalar(self, value, index=None):
+        super(SerialNumber, self)._validate_scalar(value)
+        if value.startswith('-'):
+            raise ValidationError(
+                name=self.name, error=_('must be at least 0')
+            )
+        if not value.isdigit():
+            if value.lower().startswith('0x'):
+                try:
+                    int(value[2:], 16)
+                except ValueError:
+                    raise ValidationError(
+                        name=self.name, error=_(
+                            _('invalid valid hex'),
+                        )
+                    )
+            else:
+                raise ValidationError(
+                    name=self.name, error=_(
+                        _('must be an integer'),
+                    )
+                )
+        if value == '0':
+            raise ValidationError(
+                name=self.name, error=_('invalid serial number 0')
+            )
