@@ -25,6 +25,7 @@ you are unfamiliar with this Python feature, see
 http://docs.python.org/ref/sequence-types.html
 """
 
+from collections.abc import Mapping
 import logging
 import operator
 import re
@@ -51,13 +52,6 @@ from ipapython.ipa_log_manager import (
     LOGGING_FORMAT_STDERR)
 from ipapython.version import VERSION, API_VERSION, DEFAULT_PLUGINS
 
-# pylint: disable=no-name-in-module, import-error
-if six.PY3:
-    from collections.abc import Mapping
-else:
-    from collections import Mapping
-# pylint: enable=no-name-in-module, import-error
-
 if six.PY3:
     unicode = str
 
@@ -460,7 +454,7 @@ class API(ReadOnly):
         if root_logger.handlers or self.env.validate_api:
             return
 
-        if self.env.debug:  # pylint: disable=using-constant-test
+        if self.env.debug:
             level = logging.DEBUG
         else:
             level = logging.INFO
@@ -484,7 +478,7 @@ class API(ReadOnly):
 
         # Add stderr handler:
         level = logging.INFO
-        if self.env.debug:  # pylint: disable=using-constant-test
+        if self.env.debug:
             level = logging.DEBUG
         else:
             if self.env.context == 'cli':
@@ -516,16 +510,19 @@ class API(ReadOnly):
                 return
 
         level = logging.INFO
-        if self.env.debug:  # pylint: disable=using-constant-test
+        if self.env.debug:
             level = logging.DEBUG
-        try:
-            handler = logging.FileHandler(self.env.log)
-        except IOError as e:
-            logger.error('Cannot open log file %r: %s', self.env.log, e)
-            return
-        handler.setLevel(level)
-        handler.setFormatter(ipa_log_manager.Formatter(LOGGING_FORMAT_FILE))
-        root_logger.addHandler(handler)
+        if self.env.log is not None:
+            try:
+                handler = logging.FileHandler(self.env.log)
+            except IOError as e:
+                logger.error('Cannot open log file %r: %s', self.env.log, e)
+            else:
+                handler.setLevel(level)
+                handler.setFormatter(
+                    ipa_log_manager.Formatter(LOGGING_FORMAT_FILE)
+                )
+                root_logger.addHandler(handler)
 
     def build_global_parser(self, parser=None, context=None):
         """
@@ -664,9 +661,9 @@ class API(ReadOnly):
             except errors.SkipPluginModule as e:
                 logger.debug("skipping plugin module %s: %s", name, e.reason)
                 continue
-            except Exception as e:
+            except Exception:
                 tb = self.env.startup_traceback
-                if tb:  # pylint: disable=using-constant-test
+                if tb:
                     logger.exception("could not load plugin module %s", name)
                 raise
 
@@ -801,8 +798,6 @@ class API(ReadOnly):
                 if not production_mode:
                     assert islocked(instance)
 
-        self.__finalized = True
-
         if not production_mode:
             lock(self)
 
@@ -827,10 +822,10 @@ class API(ReadOnly):
 
 
 class IPAHelpFormatter(optparse.IndentedHelpFormatter):
-    def format_epilog(self, text):
+    def format_epilog(self, epilog):
         text_width = self.width - self.current_indent
         indent = " " * self.current_indent
-        lines = text.splitlines()
+        lines = epilog.splitlines()
         result = '\n'.join(
             textwrap.fill(line, text_width, initial_indent=indent,
                 subsequent_indent=indent)
