@@ -20,10 +20,10 @@
 from pkg_resources import parse_version
 
 # The full version including strings
-VERSION = "4.10.2"
+VERSION = "4.11.1"
 
 # A fuller version including the vendor tag (e.g. 3.3.3-34.fc20)
-VENDOR_VERSION = "4.10.2"
+VENDOR_VERSION = "4.11.1"
 
 
 # Just the numeric portion of the version so one can do direct numeric
@@ -43,11 +43,11 @@ VENDOR_VERSION = "4.10.2"
 #   IPA 3.2.1:  NUM_VERSION=30201
 #   IPA 3.2.99: NUM_VERSION=30299 (development version)
 #   IPA 3.3.0:  NUM_VERSION=30300
-NUM_VERSION = 41002
+NUM_VERSION = 41101
 
 
 # The version of the API.
-API_VERSION = "2.252"
+API_VERSION = "2.253"
 
 
 DEFAULT_PLUGINS = frozenset(l.strip() for l in """
@@ -393,6 +393,9 @@ output_show/1
 param/1
 param_find/1
 param_show/1
+passkeyconfig/1
+passkeyconfig_mod/1
+passkeyconfig_show/1
 passwd/1
 permission/1
 permission_add/1
@@ -518,6 +521,7 @@ stageuser_add/1
 stageuser_add_cert/1
 stageuser_add_certmapdata/1
 stageuser_add_manager/1
+stageuser_add_passkey/1
 stageuser_add_principal/1
 stageuser_del/1
 stageuser_find/1
@@ -525,6 +529,7 @@ stageuser_mod/1
 stageuser_remove_cert/1
 stageuser_remove_certmapdata/1
 stageuser_remove_manager/1
+stageuser_remove_passkey/1
 stageuser_remove_principal/1
 stageuser_show/1
 subid/1
@@ -613,6 +618,7 @@ user_add/1
 user_add_cert/1
 user_add_certmapdata/1
 user_add_manager/1
+user_add_passkey/1
 user_add_principal/1
 user_del/1
 user_disable/1
@@ -622,6 +628,7 @@ user_mod/1
 user_remove_cert/1
 user_remove_certmapdata/1
 user_remove_manager/1
+user_remove_passkey/1
 user_remove_principal/1
 user_show/1
 user_stage/1
@@ -651,4 +658,4 @@ vaultcontainer_show/1
 whoami/1
 """.strip().splitlines())
 
-KRB5_BUILD_VERSION = parse_version("1.19.2")
+KRB5_BUILD_VERSION = parse_version("1.21")
