@@ -48,6 +48,7 @@ from ipalib.install import certstore
 from ipalib.util import strip_csr_header
 from ipalib.text import _
 from ipaplatform.paths import paths
+from ipaplatform.tasks import tasks
 
 
 logger = logging.getLogger(__name__)
@@ -69,9 +70,16 @@ def get_cert_nickname(cert):
 
 def install_pem_from_p12(p12_fname, p12_passwd, pem_fname):
     pwd = ipautil.write_tmp_file(p12_passwd)
-    ipautil.run([paths.OPENSSL, "pkcs12", "-nokeys", "-clcerts",
-                 "-in", p12_fname, "-out", pem_fname,
-                 "-passin", "file:" + pwd.name])
+    args = [paths.OPENSSL, "pkcs12", "-nokeys", "-clcerts",
+            "-in", p12_fname, "-out", pem_fname,
+            "-passin", "file:" + pwd.name]
+    # the PKCS12 MAC requires PKCS12KDF which is not an approved FIPS
+    # algorithm and cannot be supported by the FIPS provider.
+    # Do not require mac verification in FIPS mode
+    fips_enabled = tasks.is_fips_enabled()
+    if fips_enabled:
+        args.append('-nomacver')
+    ipautil.run(args)
 
 
 def install_key_from_p12(
@@ -85,17 +93,16 @@ def install_key_from_p12(
         args.extend(['-passout', 'file:{}'.format(out_passwd_fname)])
     else:
         args.append('-nodes')
+    # the PKCS12 MAC requires PKCS12KDF which is not an approved FIPS
+    # algorithm and cannot be supported by the FIPS provider.
+    # Do not require mac verification in FIPS mode
+    fips_enabled = tasks.is_fips_enabled()
+    if fips_enabled:
+        args.append('-nomacver')
 
     ipautil.run(args, umask=0o077)
 
 
-def export_pem_p12(pkcs12_fname, pkcs12_pwd_fname, nickname, pem_fname):
-    ipautil.run([paths.OPENSSL, "pkcs12",
-                 "-export", "-name", nickname,
-                 "-in", pem_fname, "-out", pkcs12_fname,
-                 "-passout", "file:" + pkcs12_pwd_fname])
-
-
 def pkcs12_to_certkeys(p12_fname, p12_passwd=None):
     """
     Deserializes pkcs12 file to python objects
@@ -110,7 +117,7 @@ def pkcs12_to_certkeys(p12_fname, p12_passwd=None):
     else:
         args.extend(["-passin", "pass:"])
 
-    pems = ipautil.run(args, capture_output=True).raw_output
+    pems = ipautil.run(args).raw_output
 
     certs = x509.load_certificate_list(pems)
     priv_keys = x509.load_private_key_list(pems)
@@ -670,6 +677,7 @@ class CertDB:
             nickname=nickname,
             principal=principal,
             subject=host,
+            dns=[host],
             passwd_fname=self.passwd_fname,
             resubmit_timeout=resubmit_timeout
         )
@@ -732,7 +740,7 @@ class _CrossProcessLock:
         self._do(self._release, owner)
 
     def _acquire(self, owner):
-        now = datetime.datetime.utcnow()
+        now = datetime.datetime.now(tz=datetime.timezone.utc)
 
         if self._locked and now >= self._expire:
             self._locked = False
@@ -780,7 +788,7 @@ class _CrossProcessLock:
         if six.PY2:
             p.readfp(fileobj)  # pylint: disable=deprecated-method
         else:
-            p.read_file(fileobj)  # pylint: disable=no-member
+            p.read_file(fileobj)
 
         try:
             self._locked = p.getboolean('lock', 'locked')
@@ -791,7 +799,8 @@ class _CrossProcessLock:
                 expire = p.get('lock', 'expire')
                 try:
                     self._expire = datetime.datetime.strptime(
-                        expire, self._DATETIME_FORMAT)
+                        expire, self._DATETIME_FORMAT).replace(
+                        tzinfo=datetime.timezone.utc)
                 except ValueError:
                     raise configparser.Error
         except configparser.Error:
