@@ -75,7 +75,6 @@ def convertDate(value):
 
     dt = dateutil.parser.parse(value)
 
-    # pylint: disable=E1101
     if dt.tzinfo is None:
         dt = datetime.datetime(*dt.timetuple()[0:6],
                                tzinfo=dateutil.tz.tzlocal())
@@ -187,7 +186,7 @@ def convertEncrypted(value, decryptor=None, pconv=base64.b64decode, econv=lambda
     return None
 
 
-class XMLKeyDerivation(six.with_metaclass(abc.ABCMeta, object)):
+class XMLKeyDerivation(metaclass=abc.ABCMeta):
     "Interface for XML Encryption 1.1 key derivation."
     @abc.abstractmethod
     def __init__(self, enckey):
@@ -238,7 +237,7 @@ def convertKeyDerivation(value):
     }.get(value.lower(), None)
 
 
-class XMLDecryptor(object):
+class XMLDecryptor:
     """This decrypts values from XML as specified in:
         * http://www.w3.org/TR/xmlenc-core/
         * RFC 6931"""
@@ -285,7 +284,7 @@ class XMLDecryptor(object):
         return out
 
 
-class PSKCKeyPackage(object):
+class PSKCKeyPackage:
     _XML = {
         'pskc:DeviceInfo': {
             'pskc:IssueNo/text()':      ('issueno',      unicode),
@@ -451,7 +450,7 @@ class PSKCKeyPackage(object):
             out['ipatoken' + key] = unicode(reducer(dates).strftime("%Y%m%d%H%M%SZ"))
 
 
-class PSKCDocument(object):
+class PSKCDocument:
     @property
     def keyname(self):
         return self.__keyname
@@ -535,11 +534,11 @@ class OTPTokenImport(admintool.AdminTool):
 
         # Verify a key is provided if one is needed.
         if self.doc.keyname is not None:
-            if self.safe_options.keyfile is None:  # pylint: disable=no-member
+            if self.safe_options.keyfile is None:
                 raise admintool.ScriptError("Encryption key required: %s!" % self.doc.keyname)
 
             # Load the keyfile.
-            keyfile = self.safe_options.keyfile  # pylint: disable=no-member
+            keyfile = self.safe_options.keyfile
             with open(keyfile) as f:
                 self.doc.setKey(f.read())
 
