@@ -26,7 +26,6 @@ import shutil
 import sys
 import tempfile
 import time
-import pwd
 import ldif
 import itertools
 
@@ -41,7 +40,7 @@ from ipapython import admintool, certdb
 from ipapython.dn import DN
 from ipaserver.install.replication import (wait_for_task, ReplicationManager,
                                            get_cs_replication_manager)
-from ipaserver.install import installutils
+from ipaserver.install import installutils, ldapupdate
 from ipaserver.install import dsinstance, httpinstance, cainstance, krbinstance
 from ipaserver.masters import get_masters
 from ipapython import ipaldap
@@ -236,6 +235,15 @@ class Restore(admintool.AdminTool):
                 raise admintool.ScriptError(
                     "Directory Manager password required")
 
+    def enable_server(self):
+        """Make sure the current server is marked as enabled"""
+        if not api.Backend.ldap2.isconnected():
+            api.Backend.ldap2.connect()
+
+        try:
+            api.Command.server_state(api.env.host, state='enabled')
+        except errors.EmptyModlist:
+            pass
 
     def run(self):
         options = self.options
@@ -346,18 +354,14 @@ class Restore(admintool.AdminTool):
                         )
                     )
 
-        pent = pwd.getpwnam(constants.DS_USER)
-
         # Temporary directory for decrypting files before restoring
         self.top_dir = tempfile.mkdtemp("ipa")
-        os.chown(self.top_dir, pent.pw_uid, pent.pw_gid)
+        constants.DS_USER.chown(self.top_dir)
         os.chmod(self.top_dir, 0o750)
         self.dir = os.path.join(self.top_dir, "ipa")
         os.mkdir(self.dir)
         os.chmod(self.dir, 0o750)
-        os.chown(self.dir, pent.pw_uid, pent.pw_gid)
-
-        cwd = os.getcwd()
+        constants.DS_USER.chown(self.dir)
 
         logger.info("Temporary setting umask to 022")
         old_umask = os.umask(0o022)
@@ -472,6 +476,12 @@ class Restore(admintool.AdminTool):
                     oddjobd.enable()
                 oddjobd.start()
                 http.remove_httpd_ccaches()
+                # update autobind configuration in case uid/gid have changed
+                ld = ldapupdate.LDAPUpdate(api=api)
+                autobind_update = os.path.join(
+                    paths.UPDATES_DIR, "49-autobind-services.update"
+                )
+                ld.update([autobind_update])
                 # have the daemons pick up their restored configs
                 tasks.systemd_daemon_reload()
                 # Restart IPA a final time.
@@ -482,11 +492,8 @@ class Restore(admintool.AdminTool):
                 result = run([paths.IPACTL, 'restart'], raiseonerr=False)
                 if result.returncode != 0:
                     logger.error('Restarting IPA failed: %s', result.error_log)
+                self.enable_server()
         finally:
-            try:
-                os.chdir(cwd)
-            except Exception as e:
-                logger.error('Cannot change directory to %s: %s', cwd, e)
             shutil.rmtree(self.top_dir)
             logger.info("Restoring umask to %s", old_umask)
             os.umask(old_umask)
@@ -596,10 +603,9 @@ class Restore(admintool.AdminTool):
         srcldiffile = os.path.join(self.dir, ldifname)
 
         if not os.path.exists(ldifdir):
-            pent = pwd.getpwnam(constants.DS_USER)
             os.mkdir(ldifdir)
             os.chmod(ldifdir, 0o770)
-            os.chown(ldifdir, pent.pw_uid, pent.pw_gid)
+            constants.DS_USER.chown(ldifdir)
 
         ipautil.backup_file(ldiffile)
         with open(ldiffile, 'w') as out_file:
@@ -609,8 +615,7 @@ class Restore(admintool.AdminTool):
                 ldif_parser.parse()
 
         # Make sure the modified ldiffile is owned by DS_USER
-        pent = pwd.getpwnam(constants.DS_USER)
-        os.chown(ldiffile, pent.pw_uid, pent.pw_gid)
+        constants.DS_USER.chown(ldiffile)
 
         if online:
             conn = self.get_connection()
@@ -637,10 +642,10 @@ class Restore(admintool.AdminTool):
             template_dir = paths.VAR_LOG_DIRSRV_INSTANCE_TEMPLATE % instance
             try:
                 os.makedirs(template_dir)
-            except OSError as e:
+            except OSError:
                 pass
 
-            os.chown(template_dir, pent.pw_uid, pent.pw_gid)
+            constants.DS_USER.chown(template_dir)
             os.chmod(template_dir, 0o770)
 
             # Restore SELinux context of template_dir
@@ -708,7 +713,6 @@ class Restore(admintool.AdminTool):
             if result.returncode != 0:
                 logger.critical("bak2db failed: %s", result.error_log)
 
-
     def restore_default_conf(self):
         '''
         Restore paths.IPA_DEFAULT_CONF to temporary directory.
@@ -716,21 +720,18 @@ class Restore(admintool.AdminTool):
         Primary purpose of this method is to get configuration for api
         finalization when restoring ipa after uninstall.
         '''
-        cwd = os.getcwd()
-        os.chdir(self.dir)
         args = ['tar',
                 '--xattrs',
                 '--selinux',
                 '-xzf',
                 os.path.join(self.dir, 'files.tar'),
                 paths.IPA_DEFAULT_CONF[1:],
-               ]
+                ]
+        result = run(args, raiseonerr=False, cwd=self.dir)
 
-        result = run(args, raiseonerr=False)
         if result.returncode != 0:
             logger.critical('Restoring %s failed: %s',
                             paths.IPA_DEFAULT_CONF, result.error_log)
-        os.chdir(cwd)
 
     def remove_old_files(self):
         """
@@ -770,25 +771,20 @@ class Restore(admintool.AdminTool):
         databases.
         '''
         logger.info("Restoring files")
-        cwd = os.getcwd()
-        os.chdir('/')
         args = ['tar',
                 '--xattrs',
                 '--selinux',
                 '-xzf',
                 os.path.join(self.dir, 'files.tar')
-               ]
+                ]
         if nologs:
             args.append('--exclude')
             args.append('var/log')
 
-        result = run(args, raiseonerr=False)
+        result = run(args, cwd='/', raiseonerr=False)
         if result.returncode != 0:
             logger.critical('Restoring files failed: %s', result.error_log)
 
-        os.chdir(cwd)
-
-
     def read_header(self):
         '''
         Read the backup file header that contains the meta data about
@@ -802,11 +798,9 @@ class Restore(admintool.AdminTool):
         self.backup_host = config.get('ipa', 'host')
         self.backup_ipa_version = config.get('ipa', 'ipa_version')
         self.backup_version = config.get('ipa', 'version')
-        # pylint: disable=no-member
         # we can assume that returned object is string and it has .split()
         # method
         self.backup_services = config.get('ipa', 'services').split(',')
-        # pylint: enable=no-member
 
     def extract_backup(self):
         '''
@@ -831,20 +825,19 @@ class Restore(admintool.AdminTool):
             logger.info('Decrypting %s', filename)
             filename = decrypt_file(self.dir, filename)
 
-        os.chdir(self.dir)
-
         args = ['tar',
                 '--xattrs',
                 '--selinux',
                 '-xzf',
                 filename,
                 '.'
-               ]
-        run(args)
+                ]
+        run(args, cwd=self.dir)
 
-        pent = pwd.getpwnam(constants.DS_USER)
-        os.chown(self.top_dir, pent.pw_uid, pent.pw_gid)
-        recursive_chown(self.dir, pent.pw_uid, pent.pw_gid)
+        constants.DS_USER.chown(self.top_dir)
+        recursive_chown(
+            self.dir, constants.DS_USER.uid, constants.DS_USER.pgid
+        )
 
         if encrypt:
             # We can remove the decoded tarball
@@ -868,7 +861,7 @@ class Restore(admintool.AdminTool):
                      paths.TOMCAT_SIGNEDAUDIT_DIR]
 
         try:
-            pent = pwd.getpwnam(constants.PKI_USER)
+            pent = constants.PKI_USER.entity
         except KeyError:
             logger.debug("No %s user exists, skipping CA directory creation",
                          constants.PKI_USER)
