@@ -26,6 +26,7 @@ import socket
 import dbus
 
 import dns.name
+from pkg_resources import parse_version
 
 from ipalib import x509
 from ipalib.install import certstore
@@ -34,6 +35,7 @@ from ipaserver.install import installutils
 from ipapython import ipaldap
 from ipapython import ipautil
 from ipapython import kernel_keyring
+from ipapython.version import KRB5_BUILD_VERSION
 from ipalib import api, errors
 from ipalib.constants import ANON_USER
 from ipalib.install import certmonger
@@ -42,15 +44,17 @@ from ipapython.dogtag import KDC_PROFILE
 
 from ipaserver.install import replication
 from ipaserver.install import certs
-from ipaserver.masters import find_providing_servers
+from ipaserver.masters import (
+    find_providing_servers,
+    PAC_TKT_SIGN_SUPPORTED,
+    PKINIT_ENABLED,
+)
 from ipaplatform.constants import constants
 from ipaplatform.tasks import tasks
 from ipaplatform.paths import paths
 
 logger = logging.getLogger(__name__)
 
-PKINIT_ENABLED = 'pkinitEnabled'
-
 MASTER_KEY_TYPE = 'aes256-sha2'
 SUPPORTED_ENCTYPES = ('aes256-sha2:special', 'aes128-sha2:special',
                       'aes256-sha2:normal', 'aes128-sha2:normal',
@@ -169,6 +173,13 @@ class KrbInstance(service.Service):
         # Add the host to the ipaserver host group
         self._ldap_update(['20-ipaservers_hostgroup.update'])
 
+    def pac_tkt_sign_support_enable(self):
+        """
+        Advertise PAC ticket signature support in master's KDC entry in LDAP
+        """
+        service.set_service_entry_config(
+            'KDC', self.fqdn, [PAC_TKT_SIGN_SUPPORTED], self.suffix)
+
     def __common_setup(self, realm_name, host_name, domain_name, admin_password):
         self.fqdn = host_name
         self.realm = realm_name.upper()
@@ -212,6 +223,10 @@ class KrbInstance(service.Service):
 
         self.__common_post_setup()
 
+        if KRB5_BUILD_VERSION >= parse_version('1.20'):
+            self.step("enable PAC ticket signature support",
+                      self.pac_tkt_sign_support_enable)
+
         self.start_creation()
 
         self.kpasswd = KpasswdInstance()
@@ -235,6 +250,10 @@ class KrbInstance(service.Service):
 
         self.__common_post_setup()
 
+        if KRB5_BUILD_VERSION >= parse_version('1.20'):
+            self.step("enable PAC ticket signature support",
+                      self.pac_tkt_sign_support_enable)
+
         self.start_creation()
 
         self.kpasswd = KpasswdInstance()
@@ -282,7 +301,7 @@ class KrbInstance(service.Service):
 
         if fips_enabled:
             supported_enctypes = list(
-                filter(lambda e: not e.startswith('camelia'),
+                filter(lambda e: not e.startswith('camellia'),
                        SUPPORTED_ENCTYPES))
         else:
             supported_enctypes = SUPPORTED_ENCTYPES
@@ -436,8 +455,8 @@ class KrbInstance(service.Service):
         krbtgt = "krbtgt/" + self.realm + "@" + self.realm
         certpath = (paths.KDC_CERT, paths.KDC_KEY)
 
+        prev_helper = None
         try:
-            prev_helper = None
             # on the first CA-ful master without '--no-pkinit', we issue the
             # certificate by contacting Dogtag directly
             ca_instances = find_providing_servers(
