@@ -500,7 +500,7 @@ class host(LDAPObject):
         Str('nshostlocation?',
             cli_name='location',
             label=_('Location'),
-            doc=_('Host location (e.g. "Lab 2")'),
+            doc=_('Host physical location hint (e.g. "Lab 2")'),
         ),
         Str('nshardwareplatform?',
             cli_name='platform',
@@ -630,9 +630,11 @@ class host(LDAPObject):
                   " authentication by SPAKE or FAST."
                   " Use 'idp' to allow External Identity Provider"
                   " authentications."
+                  " Use 'passkey' to allow passkey-based 2FA authentications."
                   " With no indicator specified,"
                   " all authentication mechanisms are allowed."),
-            values=(u'radius', u'otp', u'pkinit', u'hardened', u'idp'),
+            values=(u'radius', u'otp', u'pkinit', u'hardened', u'idp',
+                    u'passkey'),
         ),
     ) + ticket_flags_params
 
