@@ -426,7 +426,8 @@ class idrange_add(LDAPCreate):
     def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
         assert isinstance(dn, DN)
 
-        is_set = lambda x: (x in entry_attrs) and (entry_attrs[x] is not None)
+        def is_set(x):
+            return entry_attrs.get(x) is not None
 
         # This needs to stay in options since there is no
         # ipanttrusteddomainname attribute in LDAP
@@ -685,11 +686,13 @@ class idrange_mod(LDAPUpdate):
                           '`ipa help idrange` for more information')
             )
 
-        is_set = lambda x: (x in entry_attrs) and (entry_attrs[x] is not None)
-        in_updated_attrs = lambda x:\
-            (x in entry_attrs and entry_attrs[x] is not None) or\
-            (x not in entry_attrs and x in old_attrs
-                and old_attrs[x] is not None)
+        def is_set(x):
+            return entry_attrs.get(x) is not None
+
+        def in_updated_attrs(x):
+            return is_set(x) or (
+                x not in entry_attrs and old_attrs.get(x) is not None
+            )
 
         # This needs to stay in options since there is no
         # ipanttrusteddomainname attribute in LDAP
