@@ -37,6 +37,7 @@ from ipalib.constants import (
     IPA_ANCHOR_PREFIX,
     SID_ANCHOR_PREFIX,
     PATTERN_GROUPUSER_NAME,
+    ERRMSG_GROUPUSER_NAME
 )
 from ipalib.plugable import Registry
 from ipalib.util import (normalize_sshpubkey, validate_sshpubkey,
@@ -178,6 +179,7 @@ class idview(LDAPObject):
         try:
             orig_entry_attrs = ldap.get_entry(dn, ['objectclass'])
         except errors.NotFound:
+            # pylint: disable=raising-bad-type, #4772
             raise self.handle_not_found(*keys)
 
         orig_objectclasses = {
@@ -268,13 +270,20 @@ class idview_show(LDAPRetrieve):
             try:
                 overrides, _truncated = ldap.find_entries(
                     filter="objectclass=%s" % objectclass,
-                    attrs_list=['ipaanchoruuid'],
+                    attrs_list=['ipaanchoruuid', 'ipaoriginaluid'],
                     base_dn=dn,
                     scope=ldap.SCOPE_ONELEVEL,
                     paged_search=True)
 
                 resolved_overrides = []
                 for override in overrides:
+                    if 'ipaoriginaluid' in override:
+                        # No need to resolve the anchor, we already know
+                        # the value
+                        resolved_overrides.append(
+                            override.single_value['ipaoriginaluid'])
+                        continue
+
                     anchor = override.single_value['ipaanchoruuid']
 
                     try:
@@ -808,8 +817,12 @@ class baseidoverride(LDAPObject):
 
     def convert_anchor_to_human_readable_form(self, entry_attrs, **options):
         if not options.get('raw'):
-            anchor = entry_attrs.single_value['ipaanchoruuid']
+            if 'ipaoriginaluid' in entry_attrs:
+                originaluid = entry_attrs.single_value['ipaoriginaluid']
+                entry_attrs.single_value['ipaanchoruuid'] = originaluid
+                return
 
+            anchor = entry_attrs.single_value['ipaanchoruuid']
             if anchor:
                 try:
                     object_name = resolve_anchor_to_object_name(
@@ -1013,7 +1026,7 @@ class idoverrideuser(baseidoverride):
     takes_params = baseidoverride.takes_params + (
         Str('uid?',
             pattern=PATTERN_GROUPUSER_NAME,
-            pattern_errmsg='may only include letters, numbers, _, -, . and $',
+            pattern_errmsg=ERRMSG_GROUPUSER_NAME.format('user'),
             maxlength=255,
             cli_name='login',
             label=_('User login'),
@@ -1066,7 +1079,7 @@ class idoverrideuser(baseidoverride):
             original_uid = resolve_anchor_to_object_name(self.backend,
                                                          self.override_object,
                                                          anchor)
-            entry_attrs['ipaOriginalUid'] = original_uid
+            entry_attrs['ipaoriginaluid'] = original_uid
 
         except (errors.NotFound, errors.ValidationError):
             # Anchor could not be resolved, this means we had to specify the
@@ -1116,7 +1129,7 @@ class idoverridegroup(baseidoverride):
     takes_params = baseidoverride.takes_params + (
         Str('cn?',
             pattern=PATTERN_GROUPUSER_NAME,
-            pattern_errmsg='may only include letters, numbers, _, -, . and $',
+            pattern_errmsg=ERRMSG_GROUPUSER_NAME.format('group'),
             maxlength=255,
             cli_name='group_name',
             label=_('Group name'),
