@@ -160,7 +160,11 @@ class i18n_messages(Command):
         "actions": {
             "apply": _("Apply"),
             "automember_rebuild": _("Rebuild auto membership"),
-            "automember_rebuild_confirm": _("Are you sure you want to rebuild auto membership?"),
+            "automember_rebuild_confirm": _(
+                "Are you sure you want to rebuild auto membership? In case of "
+                "a high number of users, hosts or groups, the operation "
+                "may require high CPU usage."
+            ),
             "automember_rebuild_success": _("Automember rebuild membership task completed"),
             "confirm": _("Are you sure you want to proceed with the action?"),
             "delete_confirm": _("Are you sure you want to delete ${object}?"),
@@ -192,6 +196,7 @@ class i18n_messages(Command):
             "type_pkinit": _("PKINIT"),
             "type_hardened": _("Hardened Password (by SPAKE or FAST)"),
             "type_idp": _("External Identity Provider"),
+            "type_passkey": _("Passkey"),
             "type_disabled": _("Disable per-user override"),
             "user_tooltip": _("<p>Per-user setting, overwrites the global setting if any option is checked.</p><p><strong>Password + Two-factor:</strong> LDAP and Kerberos allow authentication with either one of the authentication types but Kerberos uses pre-authentication method which requires to use armor ccache.</p><p><strong>RADIUS with another type:</strong> Kerberos always use RADIUS, but LDAP never does. LDAP only recognize the password and two-factor authentication options.</p>"),
         },
@@ -1219,6 +1224,18 @@ class i18n_messages(Command):
                 "type_hotp": _("Counter-based (HOTP)"),
                 "type_totp": _("Time-based (TOTP)"),
             },
+            "passkey": {
+                "adder_title": _("Add Passkey"),
+                "data_label": _("Passkey"),
+                "deleter_content": _(
+                    "Do you want to remove passkey ${passkey}?"),
+                "deleter_title": _("Remove Passkey"),
+                "type_discoverable": _("(discoverable) "),
+                "type_serverside": _("(server-side) ")
+            },
+            "passkeyconfig": {
+                "options": _("Options")
+            },
             "permission": {
                 "add_custom_attr": _("Add Custom Attribute"),
                 "attribute": _("Attribute"),
