@@ -30,11 +30,11 @@ from ipalib.request import context
 from ipapython.dn import DN
 
 import base64
+import urllib
 import uuid
 import os
 
 import six
-from six.moves import urllib
 
 if six.PY3:
     unicode = str
@@ -245,7 +245,7 @@ class otptoken(LDAPObject):
         Int('ipatokentotpclockoffset?',
             cli_name='offset',
             label=_('Clock offset'),
-            doc=_('TOTP token / FreeIPA server time difference'),
+            doc=_('TOTP token / IPA server time difference'),
             default=0,
             autofill=True,
             flags=('no_update'),
