@@ -62,6 +62,10 @@ policy.
 Group password policies are automatically removed when the groups they
 are associated with are removed.
 
+Grace period defines the number of LDAP logins allowed after expiration.
+-1 means do not enforce expiration to match previous behavior. 0 allows
+no additional logins after expiration.
+
 EXAMPLES:
 
  Modify the global policy:
@@ -244,7 +248,7 @@ class pwpolicy(LDAPObject):
         'krbpwdmaxfailure', 'krbpwdfailurecountinterval',
         'krbpwdlockoutduration', 'ipapwdmaxrepeat',
         'ipapwdmaxsequence', 'ipapwddictcheck',
-        'ipapwdusercheck',
+        'ipapwdusercheck', 'passwordgracelimit',
     ]
     managed_permissions = {
         'System: Read Group Password Policy': {
@@ -257,7 +261,7 @@ class pwpolicy(LDAPObject):
                 'krbpwdlockoutduration', 'krbpwdmaxfailure',
                 'krbpwdmindiffchars', 'krbpwdminlength', 'objectclass',
                 'ipapwdmaxrepeat', 'ipapwdmaxsequence', 'ipapwddictcheck',
-                'ipapwdusercheck',
+                'ipapwdusercheck', 'passwordgracelimit',
             },
             'default_privileges': {
                 'Password Policy Readers',
@@ -285,7 +289,7 @@ class pwpolicy(LDAPObject):
                 'krbpwdhistorylength', 'krbpwdlockoutduration',
                 'krbpwdmaxfailure', 'krbpwdmindiffchars', 'krbpwdminlength',
                 'ipapwdmaxrepeat', 'ipapwdmaxsequence', 'ipapwddictcheck',
-                'ipapwdusercheck',
+                'ipapwdusercheck', 'passwordgracelimit',
             },
             'replaces': [
                 '(targetattr = "krbmaxpwdlife || krbminpwdlife || krbpwdhistorylength || krbpwdmindiffchars || krbpwdminlength || krbpwdmaxfailure || krbpwdfailurecountinterval || krbpwdlockoutduration")(target = "ldap:///cn=*,cn=$REALM,cn=kerberos,$SUFFIX")(version 3.0;acl "permission:Modify Group Password Policy";allow (write) groupdn = "ldap:///cn=Modify Group Password Policy,cn=permissions,cn=pbac,$SUFFIX";)',
@@ -396,6 +400,16 @@ class pwpolicy(LDAPObject):
             doc=_('Check if the password contains the username'),
             default=False,
         ),
+        Int(
+            'passwordgracelimit?',
+            cli_name='gracelimit',
+            label=_('Grace login limit'),
+            doc=_('Number of LDAP authentications allowed after expiration'),
+            minvalue=-1,
+            maxvalue=Int.MAXINT,
+            default=-1,
+            autofill=True,
+        ),
     )
 
     def get_dn(self, *keys, **options):
@@ -443,7 +457,7 @@ class pwpolicy(LDAPObject):
             for attr in ['ipapwdmaxrepeat', 'ipapwdmaxsequence',
                          'ipapwddictcheck', 'ipapwdusercheck']:
                 val = get_val(entry, attr)
-                if val not in ('FALSE', '0', 0, None):
+                if val not in (False, 'FALSE', '0', 0, None):
                     return True
             return False
 
@@ -526,6 +540,7 @@ class pwpolicy_add(LDAPCreate):
             keys[-1], krbpwdpolicyreference=dn,
             cospriority=options.get('cospriority')
         )
+
         return dn
 
     def post_callback(self, ldap, dn, entry_attrs, *keys, **options):
@@ -574,7 +589,9 @@ class pwpolicy_mod(LDAPUpdate):
     def pre_callback(self, ldap, dn, entry_attrs, attrs_list, *keys, **options):
         assert isinstance(dn, DN)
         old_entry_attrs = ldap.get_entry(dn, ['objectclass'])
-        if 'ipapwdpolicy' not in old_entry_attrs['objectclass']:
+        if not self.obj.has_objectclass(
+            old_entry_attrs['objectclass'], 'ipapwdpolicy'
+        ):
             old_entry_attrs['objectclass'].append('ipapwdpolicy')
             entry_attrs['objectclass'] = old_entry_attrs['objectclass']
         self.obj.convert_time_on_input(entry_attrs)
