@@ -614,9 +614,11 @@ class service(LDAPObject):
                   " Use 'idp' to allow authentication against an external"
                   " Identity Provider supporting OAuth 2.0 Device"
                   " Authorization Flow (RFC 8628)."
+                  " Use 'passkey' to allow passkey-based 2FA authentications."
                   " With no indicator specified,"
                   " all authentication mechanisms are allowed."),
-            values=(u'radius', u'otp', u'pkinit', u'hardened', u'idp'),
+            values=(u'radius', u'otp', u'pkinit', u'hardened', u'idp',
+                    u'passkey'),
         ),
     ) + ticket_flags_params
 
