@@ -23,6 +23,10 @@ from ipalib.frontend import Command, Object
 from ipalib import api, errors
 from ipalib import Bytes, Flag, Str, StrEnum
 from ipalib import output
+from ipalib.constants import (
+    VAULT_WRAPPING_SUPPORTED_ALGOS, VAULT_WRAPPING_DEFAULT_ALGO,
+    VAULT_WRAPPING_3DES, VAULT_WRAPPING_AES128_CBC,
+)
 from ipalib.crud import PKQuery, Retrieve
 from ipalib.parameters import Principal
 from ipalib.plugable import Registry
@@ -34,18 +38,13 @@ from .service import normalize_principal, validate_realm
 from ipalib import _, ngettext
 from ipapython import kerberos
 from ipapython.dn import DN
+from ipaserver.masters import is_service_enabled
 
 if api.env.in_server:
     import pki.account
     import pki.key
-    # pylint: disable=no-member
-    try:
-        # pki >= 10.4.0
-        from pki.crypto import DES_EDE3_CBC_OID
-    except ImportError:
-        DES_EDE3_CBC_OID = pki.key.KeyClient.DES_EDE3_CBC_OID
-    # pylint: enable=no-member
-
+    from pki.crypto import DES_EDE3_CBC_OID
+    from pki.crypto import AES_128_CBC_OID
 
 if six.PY3:
     unicode = str
@@ -653,6 +652,20 @@ class vault(LDAPObject):
         ),
     )
 
+    def _translate_algorithm(self, name):
+        if name is None:
+            name = VAULT_WRAPPING_DEFAULT_ALGO
+        if name not in VAULT_WRAPPING_SUPPORTED_ALGOS:
+            msg = _("{algo} is not a supported vault wrapping algorithm")
+            raise errors.ValidationError(msg.format(algo=name))
+        if name == VAULT_WRAPPING_3DES:
+            return DES_EDE3_CBC_OID
+        elif name == VAULT_WRAPPING_AES128_CBC:
+            return AES_128_CBC_OID
+        else:
+            # unreachable
+            raise ValueError(name)
+
     def get_dn(self, *keys, **options):
         """
         Generates vault DN from parameters.
@@ -993,14 +1006,18 @@ class vaultconfig_show(Retrieve):
     )
 
     def execute(self, *args, **options):
-
         if not self.api.Command.kra_is_enabled()['result']:
             raise errors.InvocationError(
                 format=_('KRA service is not enabled'))
 
+        config = dict(
+            wrapping_supported_algorithms=VAULT_WRAPPING_SUPPORTED_ALGOS,
+            wrapping_default_algorithm=VAULT_WRAPPING_DEFAULT_ALGO,
+        )
+
         with self.api.Backend.kra.get_client() as kra_client:
             transport_cert = kra_client.system_certs.get_transport_cert()
-            config = {'transport_cert': transport_cert.binary}
+            config['transport_cert'] = transport_cert.binary
 
         self.api.Object.config.show_servroles_attributes(
             config, "KRA server", **options)
@@ -1030,6 +1047,13 @@ class vault_archive_internal(PKQuery):
             'nonce',
             doc=_('Nonce'),
         ),
+        StrEnum(
+            'wrapping_algo?',
+            doc=_('Key wrapping algorithm'),
+            values=VAULT_WRAPPING_SUPPORTED_ALGOS,
+            default=VAULT_WRAPPING_3DES,
+            autofill=True,
+        ),
     )
 
     has_output = output.standard_entry
@@ -1046,6 +1070,9 @@ class vault_archive_internal(PKQuery):
         nonce = options.pop('nonce')
         wrapped_session_key = options.pop('session_key')
 
+        wrapping_algo = options.pop('wrapping_algo', None)
+        algorithm_oid = self.obj._translate_algorithm(wrapping_algo)
+
         # retrieve vault info
         vault = self.api.Command.vault_show(*args, **options)['result']
 
@@ -1072,7 +1099,7 @@ class vault_archive_internal(PKQuery):
                 pki.key.KeyClient.PASS_PHRASE_TYPE,
                 wrapped_vault_data,
                 wrapped_session_key,
-                algorithm_oid=DES_EDE3_CBC_OID,
+                algorithm_oid=algorithm_oid,
                 nonce_iv=nonce,
             )
 
@@ -1099,6 +1126,13 @@ class vault_retrieve_internal(PKQuery):
             'session_key',
             doc=_('Session key wrapped with transport certificate'),
         ),
+        StrEnum(
+            'wrapping_algo?',
+            doc=_('Key wrapping algorithm'),
+            values=VAULT_WRAPPING_SUPPORTED_ALGOS,
+            default=VAULT_WRAPPING_3DES,
+            autofill=True,
+        ),
     )
 
     has_output = output.standard_entry
@@ -1113,6 +1147,9 @@ class vault_retrieve_internal(PKQuery):
 
         wrapped_session_key = options.pop('session_key')
 
+        wrapping_algo = options.pop('wrapping_algo', None)
+        algorithm_oid = self.obj._translate_algorithm(wrapping_algo)
+
         # retrieve vault info
         vault = self.api.Command.vault_show(*args, **options)['result']
 
@@ -1133,6 +1170,9 @@ class vault_retrieve_internal(PKQuery):
 
             key_info = response.key_infos[0]
 
+            # XXX hack
+            kra_client.keys.encrypt_alg_oid = algorithm_oid
+
             # retrieve encrypted data from KRA
             key = kra_client.keys.retrieve_key(
                 key_info.get_key_id(),
@@ -1225,14 +1265,5 @@ class kra_is_enabled(Command):
     has_output = output.standard_value
 
     def execute(self, *args, **options):
-        base_dn = DN(('cn', 'masters'), ('cn', 'ipa'), ('cn', 'etc'),
-                     self.api.env.basedn)
-        filter = '(&(objectClass=ipaConfigObject)(cn=KRA))'
-        try:
-            self.api.Backend.ldap2.find_entries(
-                base_dn=base_dn, filter=filter, attrs_list=[])
-        except errors.NotFound:
-            result = False
-        else:
-            result = True
+        result = is_service_enabled('KRA', conn=self.api.Backend.ldap2)
         return dict(result=result, value=pkey_to_value(None, options))
