@@ -10,6 +10,7 @@ import pytest
 
 from ipalib.constants import IPA_CA_RECORD
 from ipatests.test_integration.base import IntegrationTest
+from ipatests.pytest_ipa.integration.firewall import Firewall
 from ipatests.pytest_ipa.integration import tasks
 from ipatests.test_integration.test_caless import CALessBase, ipa_certs_cleanup
 from ipatests.test_integration.test_random_serial_numbers import (
@@ -85,6 +86,9 @@ def prepare_acme_client(master, client):
     acme_host = f'{IPA_CA_RECORD}.{master.domain.name}'
     acme_server = f'https://{acme_host}/acme/directory'
 
+    # enable firewall rule on client
+    Firewall(client).enable_services(["http", "https"])
+
     # install acme client packages
     if not skip_certbot_tests:
         tasks.install_packages(client, ['certbot'])
@@ -600,7 +604,12 @@ def issue_and_expire_acme_cert():
         # move system date to expire acme cert
         for host in hosts:
             tasks.kdestroy_all(host)
-            tasks.move_date(host, 'stop', '+90days+60minutes')
+            tasks.move_date(host, 'stop', '+90days+2hours')
+
+        # restart ipa services as date moved and wait to get things settle
+        time.sleep(10)
+        master.run_command(['ipactl', 'restart'])
+        time.sleep(10)
 
         tasks.get_kdcinfo(master)
         # Note raiseonerr=False:
@@ -621,7 +630,16 @@ def issue_and_expire_acme_cert():
 
     # move back date
     for host in hosts:
-        tasks.move_date(host, 'start', '-90days-60minutes')
+        tasks.move_date(host, 'start', '-90days-2hours')
+
+    # restart ipa services as date moved and wait to get things settle
+    # if the internal fixture was not called (for instance because the test
+    # was skipped), hosts = [] and hosts[0] would produce an IndexError
+    # exception.
+    if hosts:
+        time.sleep(10)
+        hosts[0].run_command(['ipactl', 'restart'])
+        time.sleep(10)
 
 
 class TestACMERenew(IntegrationTest):
@@ -956,7 +974,7 @@ class TestACMEPrune(IntegrationTest):
         )
         assert f'Number of entries returned {no_of_cert - search_size_limit}'
 
-    def test_prune_config_show(self, issue_and_expire_acme_cert):
+    def test_prune_config_show(self):
         """Test to check config-show command shows set param"""
         if (tasks.get_pki_version(self.master)
            < tasks.parse_version('11.3.0')):
@@ -997,7 +1015,7 @@ class TestACMEPrune(IntegrationTest):
         assert 'Request Search Time Limit: 0' in result.stdout_text
         assert 'cron Schedule: 0 0 1 * *' in result.stdout_text
 
-    def test_prune_disable(self, issue_and_expire_acme_cert):
+    def test_prune_disable(self):
         """Test prune command throw error after disabling the pruning"""
         if (tasks.get_pki_version(self.master)
            < tasks.parse_version('11.3.0')):
