@@ -6,17 +6,22 @@
 Module provides tests which testing ability of various certificate
 related scenarios.
 """
+import os
+
 import ipaddress
 import pytest
 import random
 import re
 import string
 import time
+import textwrap
 
 from ipaplatform.paths import paths
+from ipapython.dn import DN
 from cryptography import x509
 from cryptography.x509.oid import ExtensionOID
 from cryptography.hazmat.backends import default_backend
+from pkg_resources import parse_version
 
 from ipatests.pytest_ipa.integration import tasks
 from ipatests.test_integration.base import IntegrationTest
@@ -58,15 +63,15 @@ def get_certmonger_request_value(host, requestid, state):
 
 class TestInstallMasterClient(IntegrationTest):
     num_clients = 1
+    topology = 'line'
 
     @classmethod
     def install(cls, mh):
-        tasks.install_master(cls.master, setup_dns=True)
-        # use master's DNS so nsupdate adds correct IP address for client
-        tasks.config_host_resolvconf_with_master_data(
-            cls.master, cls.clients[0]
-        )
-        tasks.install_client(cls.master, cls.clients[0])
+        super().install(mh)
+
+        # time to look into journal logs in
+        # test_certmonger_ipa_responder_jsonrpc
+        cls.since = time.strftime('%Y-%m-%d %H:%M:%S')
 
     def test_cacert_file_appear_with_option_F(self):
         """Test if getcert creates cacert file with -F option
@@ -78,11 +83,13 @@ class TestInstallMasterClient(IntegrationTest):
 
         related: https://pagure.io/freeipa/issue/8105
         """
-        cmd_arg = ['ipa-getcert', 'request',
-                   '-f', '/etc/pki/tls/certs/test.pem',
-                   '-k', '/etc/pki/tls/private/test.key',
-                   '-K', 'test/%s' % self.clients[0].hostname,
-                   '-F', '/etc/pki/tls/test.CA']
+        cmd_arg = [
+            "ipa-getcert", "request",
+            "-f", os.path.join(paths.OPENSSL_CERTS_DIR, "test.pem"),
+            "-k", os.path.join(paths.OPENSSL_PRIVATE_DIR, "test.key"),
+            "-K", "test/%s" % self.clients[0].hostname,
+            "-F", os.path.join(paths.OPENSSL_DIR, "test.CA"),
+        ]
         result = self.clients[0].run_command(cmd_arg)
         request_id = re.findall(r'\d+', result.stdout_text)
 
@@ -90,13 +97,36 @@ class TestInstallMasterClient(IntegrationTest):
         status = tasks.wait_for_request(self.clients[0], request_id[0], 50)
         assert status == "MONITORING"
 
-        self.clients[0].run_command(['ls', '-l', '/etc/pki/tls/test.CA'])
+        self.clients[0].run_command(
+            ["ls", "-l", os.path.join(paths.OPENSSL_DIR, "test.CA")]
+        )
+
+    def test_certmonger_ipa_responder_jsonrpc(self):
+        """Test certmonger IPA responder switched to JSONRPC
+
+        This is to test if certmonger IPA responder swithed to JSONRPC
+        from XMLRPC
+
+        This test utilizes the cert request made in previous test.
+        (test_cacert_file_appear_with_option_F)
+
+        related: https://pagure.io/freeipa/issue/3299
+        """
+        # check that request is made against /ipa/json so that
+        # IPA enforce json data type
+        exp_str = 'Submitting request to "https://{}/ipa/json"'.format(
+            self.master.hostname
+        )
+        result = self.clients[0].run_command([
+            'journalctl', '-u', 'certmonger', '--since={}'.format(self.since)
+        ])
+        assert exp_str in result.stdout_text
 
     def test_ipa_getcert_san_aci(self):
         """Test for DNS and IP SAN extensions + ACIs
         """
         hostname = self.clients[0].hostname
-        certfile = '/etc/pki/tls/certs/test2.pem'
+        certfile = os.path.join(paths.OPENSSL_CERTS_DIR, "test2.pem")
 
         tasks.kinit_admin(self.master)
 
@@ -117,7 +147,7 @@ class TestInstallMasterClient(IntegrationTest):
         cmd_arg = [
             'ipa-getcert', 'request', '-v', '-w',
             '-f', certfile,
-            '-k', '/etc/pki/tls/private/test2.key',
+            '-k', os.path.join(paths.OPENSSL_PRIVATE_DIR, "test2.key"),
             '-K', f'test/{hostname}',
             '-D', hostname,
             '-A', self.clients[0].ip,
@@ -155,6 +185,34 @@ class TestInstallMasterClient(IntegrationTest):
         )
         assert "profile: caServerCert" in result.stdout_text
 
+    def test_multiple_user_certificates(self):
+        """Test that a user may be issued multiple certificates"""
+        ldap = self.master.ldap_connect()
+
+        user = 'user1'
+
+        tasks.kinit_admin(self.master)
+        tasks.user_add(self.master, user)
+
+        for id in (0, 1):
+            csr_file = f'{id}.csr'
+            key_file = f'{id}.key'
+            cert_file = f'{id}.crt'
+            openssl_cmd = [
+                'openssl', 'req', '-newkey', 'rsa:2048', '-keyout', key_file,
+                '-nodes', '-out', csr_file, '-subj', '/CN=' + user]
+            self.master.run_command(openssl_cmd)
+
+            cmd_args = ['ipa', 'cert-request', '--principal', user,
+                        '--certificate-out', cert_file, csr_file]
+            self.master.run_command(cmd_args)
+
+        # easier to count by pulling the LDAP entry
+        entry = ldap.get_entry(DN(('uid', user), ('cn', 'users'),
+                               ('cn', 'accounts'), self.master.domain.basedn))
+
+        assert len(entry.get('usercertificate')) == 2
+
     @pytest.fixture
     def test_subca_certs(self):
         """
@@ -182,9 +240,11 @@ class TestInstallMasterClient(IntegrationTest):
         self.master.run_command(["ipa", "ca-disable", "mysubca"])
         self.master.run_command(["ipa", "ca-del", "mysubca"])
         self.master.run_command(
-            ["rm", "-fv", "/etc/pki/tls/private/test.key"]
+            ["rm", "-fv", os.path.join(paths.OPENSSL_PRIVATE_DIR, "test.key")]
+        )
+        self.master.run_command(
+            ["rm", "-fv", os.path.join(paths.OPENSSL_CERTS_DIR, "test.pem")]
         )
-        self.master.run_command(["rm", "-fv", "/etc/pki/tls/certs/test.pem"])
 
     def test_getcert_list_profile_using_subca(self, test_subca_certs):
         """
@@ -199,10 +259,8 @@ class TestInstallMasterClient(IntegrationTest):
             "ipa",
             "-I",
             "test-request",
-            "-k",
-            "/etc/pki/tls/private/test.key",
-            "-f",
-            "/etc/pki/tls/certs/test.pem",
+            "-k", os.path.join(paths.OPENSSL_PRIVATE_DIR, "test.key"),
+            "-f", os.path.join(paths.OPENSSL_CERTS_DIR, "test.pem"),
             "-D",
             self.master.hostname,
             "-K",
@@ -230,6 +288,16 @@ class TestInstallMasterClient(IntegrationTest):
             raise AssertionError("certmonger request is "
                                  "in state {}". format(status))
 
+    def test_getcert_notafter_output(self):
+        """Test that currrent certmonger includes NotBefore in output"""
+        result = self.master.run_command(["certmonger", "-v"]).stdout_text
+        if parse_version(result.split()[1]) < parse_version('0.79.14'):
+            raise pytest.skip("not_before not provided in this version")
+        result = self.master.run_command(
+            ["getcert", "list", "-f", paths.HTTPD_CERT_FILE]
+        ).stdout_text
+        assert 'issued:' in result
+
 
 class TestCertmongerRekey(IntegrationTest):
 
@@ -245,12 +313,21 @@ class TestCertmongerRekey(IntegrationTest):
                 string.ascii_lowercase
             ) for i in range(10)
         )
-        self.master.run_command([
-            'ipa-getcert', 'request',
-            '-f', '/etc/pki/tls/certs/{}.pem'.format(self.request_id),
-            '-k', '/etc/pki/tls/private/{}.key'.format(self.request_id),
-            '-I', self.request_id,
-            '-K', 'test/{}'.format(self.master.hostname)])
+        self.master.run_command(
+            [
+                'ipa-getcert', 'request',
+                '-f',
+                os.path.join(
+                    paths.OPENSSL_CERTS_DIR, f"{self.request_id}.pem",
+                ),
+                '-k',
+                os.path.join(
+                    paths.OPENSSL_PRIVATE_DIR, f"{self.request_id}.key"
+                ),
+                '-I', self.request_id,
+                '-K', 'test/{}'.format(self.master.hostname)
+            ]
+        )
         status = tasks.wait_for_request(self.master, self.request_id, 100)
         assert status == "MONITORING"
 
@@ -260,16 +337,20 @@ class TestCertmongerRekey(IntegrationTest):
                                  '-i', self.request_id])
         self.master.run_command(
             [
-                'rm',
-                '-rf',
-                '/etc/pki/tls/certs/{}.pem'.format(self.request_id)
+                "rm",
+                "-rf",
+                os.path.join(
+                    paths.OPENSSL_CERTS_DIR, f"{self.request_id}.pem"
+                ),
             ]
         )
         self.master.run_command(
             [
-                'rm',
-                '-rf',
-                '/etc/pki/tls/private/{}.key'.format(self.request_id)
+                "rm",
+                "-rf",
+                os.path.join(
+                    paths.OPENSSL_PRIVATE_DIR, f"{self.request_id}.key"
+                ),
             ]
         )
 
@@ -283,7 +364,7 @@ class TestCertmongerRekey(IntegrationTest):
         related: https://bugzilla.redhat.com/show_bug.cgi?id=1249165
         """
         certdata = self.master.get_file_contents(
-            '/etc/pki/tls/certs/{}.pem'.format(self.request_id)
+            os.path.join(paths.OPENSSL_CERTS_DIR, f"{self.request_id}.pem")
         )
         cert = x509.load_pem_x509_certificate(
             certdata, default_backend()
@@ -299,7 +380,7 @@ class TestCertmongerRekey(IntegrationTest):
         assert status == "MONITORING"
 
         certdata = self.master.get_file_contents(
-            '/etc/pki/tls/certs/{}.pem'.format(self.request_id)
+            os.path.join(paths.OPENSSL_CERTS_DIR, f"{self.request_id}.pem")
         )
         cert = x509.load_pem_x509_certificate(
             certdata, default_backend()
@@ -345,37 +426,6 @@ class TestCertmongerRekey(IntegrationTest):
                                           '-I', self.request_id])
         assert self.request_id in result.stdout_text
 
-    def test_rekey_keytype_DSA(self):
-        """Test certmonger rekey command works fine
-
-        Test is to check if -G (keytype) with DSA fails
-
-        related: https://bugzilla.redhat.com/show_bug.cgi?id=1249165
-        """
-        result = self.master.run_command([
-            'ipa-getcert', 'request',
-            '-f', '/etc/pki/tls/certs/test_dsa.pem',
-            '-k', '/etc/pki/tls/private/test_dsa.key',
-            '-K', 'test/{}'.format(self.master.hostname)])
-        req_id = re.findall(r'\d+', result.stdout_text)
-        status = tasks.wait_for_request(self.master, req_id[0], 100)
-        assert status == "MONITORING"
-
-        # rekey with RSA key type
-        self.master.run_command(['getcert', 'rekey',
-                                 '-i', req_id[0],
-                                 '-g', '3072',
-                                 '-G', 'DSA'])
-        time.sleep(100)
-        # look for keytpe as DSA in request file
-        self.master.run_command([
-            'grep', 'DSA', '/var/lib/certmonger/requests/{}'.format(req_id[0])
-        ])
-
-        err_msg = 'Unable to create enrollment request: Invalid Request'
-        result = self.master.run_command(['getcert', 'list', '-i', req_id[0]])
-        assert err_msg in result.stdout_text
-
 
 class TestCertmongerInterruption(IntegrationTest):
     num_replicas = 1
@@ -466,3 +516,119 @@ class TestCertmongerInterruption(IntegrationTest):
 
         assert ca_error is None
         assert state == 'CA_WORKING'
+
+
+class TestCAShowErrorHandling(IntegrationTest):
+    num_replicas = 1
+
+    @classmethod
+    def install(cls, mh):
+        tasks.install_master(cls.master)
+        tasks.install_replica(cls.master, cls.replicas[0])
+
+    def test_ca_show_error_handling(self):
+        """
+        Test to verify if the case of a request
+        for /ca/rest/authority/{id}/cert (or .../chain)
+        where {id} is an unknown authority ID.
+
+        Test Steps:
+        1. Setup a freeipa server and a replica
+        2. Stop ipa-custodia service on replica
+        3. Create a LWCA on the replica
+        4. Verify LWCA is recognized on the server
+        5. Run `ipa ca-show <LWCA>`
+
+        PKI Github Link: https://github.com/dogtagpki/pki/pull/3605/
+        """
+        self.replicas[0].run_command(['systemctl', 'stop', 'ipa-custodia'])
+        lwca = 'lwca1'
+        result = self.replicas[0].run_command([
+            'ipa', 'ca-add', lwca, '--subject', 'CN=LWCA 1'
+        ])
+        assert 'Created CA "{}"'.format(lwca) in result.stdout_text
+        result = self.master.run_command(['ipa', 'ca-find'])
+        assert 'Name: {}'.format(lwca) in result.stdout_text
+        result = self.master.run_command(
+            ['ipa', 'ca-show', lwca, ],
+            raiseonerr=False
+        )
+        error_msg = 'ipa: ERROR: The certificate for ' \
+                    '{} is not available on this server.'.format(lwca)
+        assert error_msg in result.stderr_text
+
+    def test_certmonger_empty_cert_not_segfault(self):
+        """Test empty cert request doesn't force certmonger to segfault
+
+        Test scenario:
+        create a cert request file in /var/lib/certmonger/requests which is
+        missing most of the required information, and ask request a new
+        certificate to certmonger. The wrong request file should not make
+        certmonger crash.
+
+        related: https://pagure.io/certmonger/issue/191
+        """
+        empty_cert_req_content = textwrap.dedent("""
+        id=dogtag-ipa-renew-agent
+        key_type=UNSPECIFIED
+        key_gen_type=UNSPECIFIED
+        key_size=0
+        key_gen_size=0
+        key_next_type=UNSPECIFIED
+        key_next_gen_type=UNSPECIFIED
+        key_next_size=0
+        key_next_gen_size=0
+        key_preserve=0
+        key_storage_type=NONE
+        key_perms=0
+        key_requested_count=0
+        key_issued_count=0
+        cert_storage_type=FILE
+        cert_perms=0
+        cert_is_ca=0
+        cert_ca_path_length=0
+        cert_no_ocsp_check=0
+        last_need_notify_check=19700101000000
+        last_need_enroll_check=19700101000000
+        template_is_ca=0
+        template_ca_path_length=-1
+        template_no_ocsp_check=0
+        state=NEED_KEY_PAIR
+        autorenew=0
+        monitor=0
+        submitted=19700101000000
+        """)
+        # stop certmonger service
+        self.master.run_command(['systemctl', 'stop', 'certmonger'])
+
+        # place an empty cert request file to certmonger request dir
+        self.master.put_file_contents(
+            os.path.join(paths.CERTMONGER_REQUESTS_DIR, '20211125062617'),
+            empty_cert_req_content
+        )
+
+        # start certmonger, it should not fail
+        self.master.run_command(['systemctl', 'start', 'certmonger'])
+
+        # request a new cert, should succeed and certmonger doesn't goes
+        # to segfault
+        result = self.master.run_command([
+            "ipa-getcert", "request",
+            "-f", os.path.join(paths.OPENSSL_CERTS_DIR, "test.pem"),
+            "-k", os.path.join(paths.OPENSSL_PRIVATE_DIR, "test.key"),
+        ])
+        request_id = re.findall(r'\d+', result.stdout_text)
+
+        # check if certificate is in MONITORING state
+        status = tasks.wait_for_request(self.master, request_id[0], 50)
+        assert status == "MONITORING"
+
+        self.master.run_command(
+            ['ipa-getcert', 'stop-tracking', '-i', request_id[0]]
+        )
+        self.master.run_command([
+            'rm', '-rf',
+            os.path.join(paths.CERTMONGER_REQUESTS_DIR, '20211125062617'),
+            os.path.join(paths.OPENSSL_CERTS_DIR, 'test.pem'),
+            os.path.join(paths.OPENSSL_PRIVATE_DIR, 'test.key')
+        ])
