@@ -4,6 +4,7 @@
 
 from __future__ import absolute_import
 
+import os
 import time
 import re
 import textwrap
@@ -11,13 +12,18 @@ import textwrap
 import pytest
 
 from ipatests.test_integration.base import IntegrationTest
+from ipatests.test_integration.test_ipahealthcheck import (
+    run_healthcheck, HEALTHCHECK_PKG
+)
 from ipatests.pytest_ipa.integration import tasks
 from ipatests.pytest_ipa.integration.tasks import (
-    assert_error, replicas_cleanup)
+    assert_error, replicas_cleanup
+)
 from ipatests.pytest_ipa.integration.firewall import Firewall
 from ipatests.pytest_ipa.integration.env_config import get_global_config
 from ipalib.constants import (
-    DOMAIN_LEVEL_1, IPA_CA_NICKNAME, CA_SUFFIX_NAME)
+    DOMAIN_LEVEL_1, IPA_CA_NICKNAME, CA_SUFFIX_NAME
+)
 from ipaplatform.paths import paths
 from ipapython import certdb
 from ipatests.test_integration.test_dns_locations import (
@@ -25,6 +31,7 @@ from ipatests.test_integration.test_dns_locations import (
 )
 from ipapython.dnsutil import DNSName
 from ipalib.constants import IPA_CA_RECORD
+from ipatests.util import xfail_context
 
 config = get_global_config()
 
@@ -95,6 +102,43 @@ class TestReplicaPromotionLevel1(ReplicaPromotionBase):
         assert result.returncode == 1
         assert expected_err in result.stderr_text
 
+    @replicas_cleanup
+    def test_install_with_host_auth_ind_set(self):
+        """ A client shouldn't be able to be promoted if it has
+        any auth indicator set in the host principal.
+        https://pagure.io/freeipa/issue/8206
+        """
+
+        client = self.replicas[0]
+        # Configure firewall first
+        Firewall(client).enable_services(["freeipa-ldap",
+                                          "freeipa-ldaps"])
+
+        client.run_command(['ipa-client-install', '-U',
+                            '--domain', self.master.domain.name,
+                            '--realm', self.master.domain.realm,
+                            '-p', 'admin',
+                            '-w', self.master.config.admin_password,
+                            '--server', self.master.hostname,
+                            '--force-join'])
+
+        tasks.kinit_admin(client)
+
+        client.run_command(['ipa', 'host-mod', '--auth-ind=otp',
+                            client.hostname])
+
+        res = client.run_command(['ipa-replica-install', '-U', '-w',
+                                  self.master.config.dirman_password],
+                                 raiseonerr=False)
+
+        client.run_command(['ipa', 'host-mod', '--auth-ind=',
+                            client.hostname])
+
+        expected_err = ("Client cannot be promoted to a replica if the host "
+                        "principal has an authentication indicator set.")
+        assert res.returncode == 1
+        assert expected_err in res.stderr_text
+
     @replicas_cleanup
     def test_one_command_installation(self):
         """
@@ -106,11 +150,11 @@ class TestReplicaPromotionLevel1(ReplicaPromotionBase):
         Firewall(self.replicas[0]).enable_services(["freeipa-ldap",
                                                     "freeipa-ldaps"])
         self.replicas[0].run_command(['ipa-replica-install', '-w',
-                                     self.master.config.admin_password,
-                                     '-n', self.master.domain.name,
-                                     '-r', self.master.domain.realm,
-                                     '--server', self.master.hostname,
-                                     '-U'])
+                                      self.master.config.admin_password,
+                                      '-n', self.master.domain.name,
+                                      '-r', self.master.domain.realm,
+                                      '--server', self.master.hostname,
+                                      '-U'])
         # Ensure that pkinit is properly configured, test for 7566
         result = self.replicas[0].run_command(['ipa-pkinit-manage', 'status'])
         assert "PKINIT is enabled" in result.stdout_text
@@ -277,7 +321,7 @@ class TestWrongClientDomain(IntegrationTest):
         result1 = client.run_command(['ipa-replica-install', '-U', '-w',
                                       self.master.config.dirman_password],
                                      raiseonerr=False)
-        assert(result1.returncode == 0), (
+        assert (result1.returncode == 0), (
             'Failed to promote the client installed with the upcase domain name')
 
     def test_client_rollback(self):
@@ -311,6 +355,24 @@ class TestWrongClientDomain(IntegrationTest):
         assert("An error occurred while removing SSSD" not in
                result.stdout_text)
 
+    def test_hostname_domain_matching(self):
+        client = self.replicas[0]
+        client.run_command(['ipa-client-install', '-U', '--domain',
+                            self.master.domain.name, '-w',
+                            self.master.config.admin_password,
+                            '-p', 'admin',
+                            '--server', self.master.hostname,
+                            '--hostname', self.master.domain.name])
+        Firewall(self.replicas[0]).enable_services(["freeipa-ldap",
+                                                    "freeipa-ldaps"])
+        result = client.run_command(['ipa-replica-install', '-U', '-w',
+                                     self.master.config.dirman_password],
+                                    raiseonerr=False)
+        assert result.returncode == 1
+        assert 'hostname cannot be the same as the domain name' \
+            in result.stderr_text
+
+
 class TestRenewalMaster(IntegrationTest):
 
     topology = 'star'
@@ -393,10 +455,80 @@ class TestRenewalMaster(IntegrationTest):
         self.assertCARenewalMaster(master, replica.hostname)
         self.assertCARenewalMaster(replica, replica.hostname)
 
+    def test_replica_concheck(self):
+        """Test cases for ipa-replica-conncheck command
+
+        Following test cases would be checked:
+        - when called with --principal (it should then prompt for a password)
+        - when called with --principal / --password
+        - when called without principal and password but with a kerberos TGT,
+          kinit admin done before calling ipa-replica-conncheck
+        - when called without principal and password, and without any kerberos
+          TGT (it should default to principal=admin and prompt for a password)
+
+          related: https://pagure.io/freeipa/issue/9047
+        """
+        exp_str1 = "Connection from replica to master is OK."
+        exp_str2 = "Connection from master to replica is OK"
+        tasks.kdestroy_all(self.replicas[0])
+        # when called with --principal (it should then prompt for a password)
+        result = self.replicas[0].run_command(
+            ['ipa-replica-conncheck', '--auto-master-check',
+             '--master', self.master.hostname,
+             '-r', self.replicas[0].domain.realm,
+             '-p', self.replicas[0].config.admin_name],
+            stdin_text=self.master.config.admin_password
+        )
+        assert result.returncode == 0
+        assert (
+            exp_str1 in result.stderr_text and exp_str2 in result.stderr_text
+        )
+
+        # when called with --principal / --password
+        result = self.replicas[0].run_command([
+            'ipa-replica-conncheck', '--auto-master-check',
+            '--master', self.master.hostname,
+            '-r', self.replicas[0].domain.realm,
+            '-p', self.replicas[0].config.admin_name,
+            '-w', self.master.config.admin_password
+        ])
+        assert result.returncode == 0
+        assert (
+            exp_str1 in result.stderr_text and exp_str2 in result.stderr_text
+        )
+
+        # when called without principal and password, and without
+        # any kerberos TGT, it should default to principal=admin
+        # and prompt for a password
+        result = self.replicas[0].run_command(
+            ['ipa-replica-conncheck', '--auto-master-check',
+             '--master', self.master.hostname,
+             '-r', self.replicas[0].domain.realm],
+            stdin_text=self.master.config.admin_password
+        )
+        assert result.returncode == 0
+        assert (
+            exp_str1 in result.stderr_text and exp_str2 in result.stderr_text
+        )
+
+        # when called without principal and password but with a kerberos TGT,
+        # kinit admin done before calling ipa-replica-conncheck
+        tasks.kinit_admin(self.replicas[0])
+        result = self.replicas[0].run_command(
+            ['ipa-replica-conncheck', '--auto-master-check',
+             '--master', self.master.hostname,
+             '-r', self.replicas[0].domain.realm]
+        )
+        assert result.returncode == 0
+        assert (
+            exp_str1 in result.stderr_text and exp_str2 in result.stderr_text
+        )
+        tasks.kdestroy_all(self.replicas[0])
+
     def test_automatic_renewal_master_transfer_ondelete(self):
         # Test that after replica uninstallation, master overtakes the cert
         # renewal master role from replica (which was previously set there)
-        tasks.uninstall_master(self.replicas[0])
+        tasks.uninstall_replica(self.master, self.replicas[0])
         result = self.master.run_command(['ipa', 'config-show']).stdout_text
         assert("IPA CA renewal master: %s" % self.master.hostname in result), (
             "Master hostname not found among CA renewal masters"
@@ -502,7 +634,8 @@ class TestSubCAkeyReplication(IntegrationTest):
     def check_subca(self, host, name, cert_nick):
         result = host.run_command(['ipa', 'ca-show', name])
         # ipa ca-show returns 0 even if the cert cannot be found locally.
-        assert "ipa: ERROR:" not in result.stderr_text
+        if "ipa: ERROR:" in result.stderr_text:
+            return False
         tasks.run_certutil(
             host, ['-L', '-n', cert_nick], paths.PKI_TOMCAT_ALIAS_DIR
         )
@@ -511,6 +644,7 @@ class TestSubCAkeyReplication(IntegrationTest):
             '-f', paths.PKI_TOMCAT_ALIAS_PWDFILE_TXT,
             '-K', '-n', cert_nick
         ])
+        return True
 
     def get_certinfo(self, host):
         result = tasks.run_certutil(
@@ -522,7 +656,11 @@ class TestSubCAkeyReplication(IntegrationTest):
         for line in result.stdout_text.splitlines():
             mo = certdb.CERT_RE.match(line)
             if mo:
-                certs[mo.group('nick')] = mo.group('flags')
+                # Strip out any token
+                nick = mo.group('nick')
+                if ':' in nick:
+                    nick = nick.split(':', maxsplit=1)[1]
+                certs[nick] = mo.group('flags')
 
         result = tasks.run_certutil(
             host,
@@ -533,7 +671,11 @@ class TestSubCAkeyReplication(IntegrationTest):
         for line in result.stdout_text.splitlines():
             mo = certdb.KEY_RE.match(line)
             if mo:
-                keys[mo.group('nick')] = mo.group('keyid')
+                # Strip out any token
+                nick = mo.group('nick')
+                if ':' in nick:
+                    nick = nick.split(':', maxsplit=1)[1]
+                keys[nick] = mo.group('keyid')
         return certs, keys
 
     def check_certdb(self, master, replica):
@@ -549,14 +691,8 @@ class TestSubCAkeyReplication(IntegrationTest):
         if master.is_fips_mode:
             # Mixed FIPS/non-FIPS installations are not supported
             assert replica.is_fips_mode
-            key_nick = self.SERVER_KEY_NICK_FIPS
-        else:
-            key_nick = self.SERVER_KEY_NICK
 
-        # expected keys, server key has different name
         expected_keys = set(expected_certs)
-        expected_keys.remove(self.SERVER_CERT_NICK)
-        expected_keys.add(key_nick)
 
         # get certs and keys from Dogtag's NSSDB
         master_certs, master_keys = self.get_certinfo(master)
@@ -568,9 +704,9 @@ class TestSubCAkeyReplication(IntegrationTest):
         assert set(master_keys) == expected_keys
         assert set(replica_keys) == expected_keys
 
-        # server keys are different
-        master_server_key = master_keys.pop(key_nick)
-        replica_server_key = replica_keys.pop(key_nick)
+        # The Server-Cert keys are unique per-machine
+        master_server_key = master_keys.pop('Server-Cert cert-pki-ca')
+        replica_server_key = replica_keys.pop('Server-Cert cert-pki-ca')
         assert master_server_key != replica_server_key
         # but key ids of other keys are equal
         assert master_keys == replica_keys
@@ -593,11 +729,18 @@ class TestSubCAkeyReplication(IntegrationTest):
         master_nick = self.add_subca(
             master, self.SUBCA_MASTER, self.SUBCA_MASTER_CN
         )
-        # give replication some time
-        time.sleep(15)
+        # give replication some time, up to 60 seconds
+        for _i in range(0,6):
+            time.sleep(10)
+            m = self.check_subca(master, self.SUBCA_MASTER, master_nick)
+            r = self.check_subca(replica, self.SUBCA_MASTER, master_nick)
+
+            if m and r:
+                break
+        else:
+            assert m, "master doesn't have the subCA"
+            assert r, "replica doesn't have the subCA"
 
-        self.check_subca(master, self.SUBCA_MASTER, master_nick)
-        self.check_subca(replica, self.SUBCA_MASTER, master_nick)
         self.check_pki_error(replica)
         self.check_certdb(master, replica)
 
@@ -608,12 +751,19 @@ class TestSubCAkeyReplication(IntegrationTest):
         replica_nick = self.add_subca(
             replica, self.SUBCA_REPLICA, self.SUBCA_REPLICA_CN
         )
-        # give replication some time
-        time.sleep(15)
+        # give replication some time, up to 60 seconds
+        for _i in range(0,6):
+            time.sleep(10)
+            r = self.check_subca(replica, self.SUBCA_REPLICA, replica_nick)
+            m = self.check_subca(master, self.SUBCA_REPLICA, replica_nick)
+
+            if m and r:
+                break
+        else:
+            assert m, "master doesn't have the subCA"
+            assert r, "replica doesn't have the subCA"
 
         # replica.run_command(['ipa-certupdate'])
-        self.check_subca(replica, self.SUBCA_REPLICA, replica_nick)
-        self.check_subca(master, self.SUBCA_REPLICA, replica_nick)
         self.check_pki_error(master)
         self.check_certdb(master, replica)
 
@@ -621,8 +771,12 @@ class TestSubCAkeyReplication(IntegrationTest):
         master = self.master
         replica = self.replicas[0]
 
-        TEST_KEY_FILE = '/etc/pki/tls/private/test_subca.key'
-        TEST_CRT_FILE = '/etc/pki/tls/private/test_subca.crt'
+        TEST_KEY_FILE = os.path.join(
+            paths.OPENSSL_PRIVATE_DIR, 'test_subca.key'
+        )
+        TEST_CRT_FILE = os.path.join(
+            paths.OPENSSL_PRIVATE_DIR, 'test_subca.crt'
+        )
 
         caacl_cmd = [
             'ipa', 'caacl-add-ca', 'hosts_services_caIPAserviceCert',
@@ -665,8 +819,8 @@ class TestSubCAkeyReplication(IntegrationTest):
         # give replication some time
         time.sleep(15)
 
-        for name in subcas:
-            self.check_subca(replica, name, subcas[name])
+        for name, cert_nick in subcas.items():
+            self.check_subca(replica, name, cert_nick)
             self.del_subca(replica, name)
 
 
@@ -692,10 +846,11 @@ class TestReplicaInstallCustodia(IntegrationTest):
         tasks.install_replica(master, replica1, setup_ca=False)
         replica1.run_command(['ipactl', 'status'])
         replica1.run_command(['systemctl', 'stop', 'ipa-custodia'])
-        replica1.run_command(['ipactl', 'status'])
+        replica1.run_command(['ipactl', 'status'], raiseonerr=False)
 
         # Install Replica2 with CA with source as Replica1.
-        tasks.install_replica(replica1, replica2, setup_ca=True)
+        tasks.install_replica(replica1, replica2, setup_ca=True,
+                              nameservers='master')
         result = replica2.run_command(['ipactl', 'status'])
         assert 'ipa-custodia Service: RUNNING' in result.stdout_text
 
@@ -809,6 +964,8 @@ class TestHiddenReplicaPromotion(IntegrationTest):
 
     @classmethod
     def install(cls, mh):
+        for srv in (cls.master, cls.replicas[0]):
+            tasks.install_packages(srv, HEALTHCHECK_PKG)
         # master with DNSSEC master
         tasks.install_master(cls.master, setup_dns=True, setup_kra=True)
         cls.master.run_command([
@@ -887,13 +1044,44 @@ class TestHiddenReplicaPromotion(IntegrationTest):
             assert values.get(hservice, set()) == hidden
 
     def test_hidden_replica_install(self):
-        # TODO: check that all services are running on hidden replica
         self._check_server_role(self.master, 'enabled')
         self._check_server_role(self.replicas[0], 'hidden')
         self._check_dnsrecords([self.master], [self.replicas[0]])
         self._check_config([self.master], [self.replicas[0]])
 
-    def test_hide_master_fails(self):
+    def test_ipahealthcheck_hidden_replica(self):
+        """Ensure that ipa-healthcheck runs successfully on all members
+        of an IPA cluster that includes a hidden replica.
+        """
+        os_version = (tasks.get_platform(self.master),
+                      tasks.get_platform_version(self.master))
+        pki_version = tasks.get_pki_version(self.master)
+
+        # verify state
+        self._check_config([self.master], [self.replicas[0]])
+        # A DNA range is needed on the replica for ipa-healthcheck to work.
+        # Create a user so that the replica gets a range.
+        tasks.user_add(self.replicas[0], 'testuser')
+        tasks.user_del(self.replicas[0], 'testuser')
+        for srv in (self.master, self.replicas[0]):
+            returncode, _unused = run_healthcheck(
+                srv,
+                failures_only=True
+            )
+            pki_too_old = \
+                (os_version[0] == 'fedora'
+                    and pki_version < tasks.parse_version('11.1.0'))\
+                or (os_version[0] == 'rhel'
+                    and os_version[1][0] == 8
+                    and pki_version < tasks.parse_version('10.12.0'))\
+                or (os_version[0] == 'rhel'
+                    and os_version[1][0] == 9
+                    and pki_version < tasks.parse_version('11.0.4'))
+            with xfail_context(pki_too_old,
+                               'https://pagure.io/freeipa/issue/8582'):
+                assert returncode == 0
+
+    def test_hide_last_visible_server_fails(self):
         # verify state
         self._check_config([self.master], [self.replicas[0]])
         # nothing to do
@@ -922,9 +1110,17 @@ class TestHiddenReplicaPromotion(IntegrationTest):
             self.replicas[0].hostname, '--state=enabled'
         ])
         self._check_server_role(self.replicas[0], 'enabled')
-        self._check_dnsrecords([self.master, self.replicas[0]])
+        tasks.wait_for_replication(
+            self.replicas[0].ldap_connect()
+        )
+        tasks.dns_update_system_records(self.master)
+        tasks.wait_for_replication(
+            self.master.ldap_connect()
+        )
         self._check_config([self.master, self.replicas[0]])
+        self._check_dnsrecords([self.master, self.replicas[0]])
 
+    def test_promote_twice_fails(self):
         result = self.replicas[0].run_command([
             'ipa', 'server-state',
             self.replicas[0].hostname, '--state=enabled'
@@ -938,6 +1134,14 @@ class TestHiddenReplicaPromotion(IntegrationTest):
             self.replicas[0].hostname, '--state=hidden'
         ])
         self._check_server_role(self.replicas[0], 'hidden')
+        tasks.wait_for_replication(
+            self.replicas[0].ldap_connect()
+        )
+        tasks.dns_update_system_records(self.master)
+        tasks.wait_for_replication(
+            self.master.ldap_connect()
+        )
+        self._check_config([self.master], [self.replicas[0]])
         self._check_dnsrecords([self.master], [self.replicas[0]])
 
     def test_replica_from_hidden(self):
@@ -1001,11 +1205,11 @@ class TestHiddenReplicaPromotion(IntegrationTest):
             stdin_text=dirman_password + '\nyes'
         )
 
-        # give replication some time
-        time.sleep(5)
+        tasks.kinit_admin(self.master)
         tasks.kinit_admin(self.replicas[0])
 
-        # FIXME: restore turns hidden replica into enabled replica
+        # restore turns a hidden replica into an enabled replica
+        # https://pagure.io/freeipa/issue/7894
         self._check_config([self.master, self.replicas[0]])
         self._check_server_role(self.replicas[0], 'enabled')
 
