@@ -4,7 +4,6 @@
 
 from __future__ import absolute_import
 
-import paramiko
 import pytest
 
 from ipaplatform.osinfo import osinfo
@@ -63,13 +62,17 @@ class TestUserPermissions(IntegrationTest):
                                  '--last', testuser,
                                  '--password'],
                                 stdin_text=testuser_password_confirmation)
-
-        # kinit as altadmin
-        self.master.run_command(['kinit', self.altadmin],
-                                stdin_text=self.master.config.admin_password)
-
-        # call ipa user-del --preserve
-        self.master.run_command(['ipa', 'user-del', '--preserve', testuser])
+        try:
+            # kinit as altadmin
+            self.master.run_command(
+                ['kinit', self.altadmin],
+                stdin_text=self.master.config.admin_password
+            )
+            # call ipa user-del --preserve
+            self.master.run_command(['ipa', 'user-del', '--preserve', testuser]
+                                    )
+        finally:
+            self.master.run_command(['ipa', 'user-del', testuser])
 
     @pytest.mark.skipif(
         not platformtasks.is_selinux_enabled(),
@@ -84,42 +87,32 @@ class TestUserPermissions(IntegrationTest):
 
         Related ticket https://pagure.io/SSSD/sssd/issue/3819.
         """
-        if self.master.is_fips_mode:  # pylint: disable=no-member
-            pytest.skip("paramiko is not compatible with FIPS mode")
 
         # Scenario: add an IPA user with non-default home dir, login through
         # ssh as this user and check that there is a SELinux user mapping
         # for the user with `semanage login -l`.
 
-        # kinit admin
-        tasks.kinit_admin(self.master)
-
-        testuser = 'testuser_selinux'
+        test_user = 'testuser_selinux'
         password = 'Secret123'
-        testuser_password_confirmation = "%s\n%s\n" % (password,
-                                                       password)
-        self.master.run_command(['ipa', 'user-add', testuser,
-                                 '--first', testuser,
-                                 '--last', testuser,
-                                 '--password',
-                                 '--homedir',
-                                 '/root/{}'.format(testuser)],
-                                stdin_text=testuser_password_confirmation)
 
-        # login to the system
-        client = paramiko.SSHClient()
-        client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
-        client.connect(self.master.hostname,
-                       username=testuser,
-                       password=password)
-        client.close()
+        tasks.kinit_admin(self.master)
+        tasks.create_active_user(
+            self.master, test_user, password=password,
+            extra_args=['--homedir', '/root/{}'.format(test_user)]
+        )
+
+        tasks.run_ssh_cmd(
+            to_host=self.master.external_hostname, username=test_user,
+            auth_method="password", password=password
+        )
 
         # check if user listed in output
         cmd = self.master.run_command(['semanage', 'login', '-l'])
-        assert testuser in cmd.stdout_text
+        assert test_user in cmd.stdout_text
 
         # call ipa user-del
-        self.master.run_command(['ipa', 'user-del', testuser])
+        tasks.kinit_admin(self.master)
+        self.master.run_command(['ipa', 'user-del', test_user])
 
     def test_stageuser_show_as_alternate_admin(self):
         """
@@ -193,6 +186,65 @@ class TestUserPermissions(IntegrationTest):
              '--user-auth-type', 'radius', '--radius-username', 'testradius',
              'testradius', '--radius', radiusproxy])
 
+    def test_delete_group_by_user_administrator(self):
+        """
+        Test that a user with sufficient privileges can delete group
+        This is a Automation for issue 6884
+        """
+        # Create a new testadmin user with a password
+        testadmin = 'tuser'
+        password = 'Secret123'
+        testgroup = 'gtest'
+
+        try:
+            tasks.create_active_user(self.master, testadmin, password)
+
+            # Add testadmin user to role "User Administrator"
+            tasks.kinit_admin(self.master)
+            self.master.run_command(['ipa', 'role-add-member',
+                                     '--users', testadmin,
+                                     'User Administrator'])
+            tasks.kdestroy_all(self.master)
+
+            # Create a test group
+            tasks.kinit_as_user(self.master, testadmin, password)
+            self.master.run_command(['ipa', 'group-add', testgroup])
+
+            # Call ipa-group-del to check if user can delete group
+            self.master.run_command(['ipa', 'group-del', testgroup])
+        finally:
+            # Cleanup
+            tasks.kinit_admin(self.master)
+            self.master.run_command(['ipa', 'user-del', testadmin])
+            self.master.run_command(['ipa', 'group-del', testgroup,
+                                     '--continue'])
+
+    def test_search_hbacrule_nonadminuser(self):
+        """
+        Test that non admin user can search hbac rule.
+
+        Related : https://pagure.io/freeipa/issue/5130
+        """
+        user = 'hbacuser'
+        password = 'Secret123'
+        hrule = 'rule1'
+
+        try:
+            tasks.create_active_user(self.master, user, password)
+            tasks.kinit_admin(self.master)
+            self.master.run_command(["ipa", "hbacrule-add", hrule])
+            tasks.kdestroy_all(self.master)
+            tasks.kinit_as_user(self.master, user, password)
+            rule = "Rule name: {0}".format(hrule)
+            result = self.master.run_command(["ipa", "hbacrule-find", hrule])
+            assert rule in result.stdout_text
+            result2 = self.master.run_command(["ipa", "hbacrule-find"])
+            assert rule in result2.stdout_text
+        finally:
+            # Cleanup
+            tasks.kinit_admin(self.master)
+            self.master.run_command(['ipa', 'user-del', user])
+            self.master.run_command(["ipa", "hbacrule-del", hrule])
 
 
 class TestInstallClientNoAdmin(IntegrationTest):
