@@ -33,7 +33,9 @@ class TestInstallKRA(IntegrationTest):
 
     @classmethod
     def install(cls, mh):
-        tasks.install_master(cls.master, setup_kra=True)
+        tasks.install_master(cls.master,
+                             setup_kra=True,
+                             random_serial=cls.random_serial)
         # do not install KRA on replica, it is part of test
         tasks.install_replica(cls.master, cls.replicas[0], setup_kra=False)
 
@@ -176,7 +178,7 @@ class TestInstallKRA(IntegrationTest):
 
         self._retrieve_secret([self.vault_name_replica_with_KRA])
 
-        ################# master #################
+        # ################ master #################
         # test master again after KRA was installed on replica
         # create vault
         self.master.run_command([
@@ -197,7 +199,7 @@ class TestInstallKRA(IntegrationTest):
 
         self._retrieve_secret([self.vault_name_master2])
 
-        ################ old vaults ###############
+        # ############### old vaults ###############
         # test if old vaults are still accessible
         self._retrieve_secret([
             self.vault_name_master,
