@@ -25,8 +25,10 @@ from ipatests.test_webui.ui_driver import UI_driver
 from ipatests.test_webui.ui_driver import screenshot
 import ipatests.test_webui.data_hbac as hbac
 import ipatests.test_webui.data_hostgroup as hostgroup
+import pytest
 
 
+@pytest.mark.tier1
 class test_hbac(UI_driver):
 
     @screenshot
@@ -136,29 +138,26 @@ class test_hbac(UI_driver):
         self.wait_for_request(n=2)
         self.assert_facet('hbactest', 'run_test')
         self.button_click('run_test')
-        self.wait_for_request(n=2)
         self.assert_text("div.hbac-test-result-panel p", 'Access Granted'.upper())
         self.button_click('prev')
         self.assert_facet('hbactest', 'rules')
         self.switch_to_facet('run_test')
+        self.wait_for_request(n=2)
         self.button_click('new_test')
         self.assert_facet('hbactest', 'user')
 
         # test pre-run validation and navigation to related facet
-        self.switch_to_facet('run_test')
-        self.button_click('run_test')
-        self.assert_dialog('message_dialog')
-        self.click_on_link('User name')
-        self.assert_facet('hbactest', 'user')
+        def __hbac_ui_click_on_run_test(self):
+            self.wait_for_request(n=2)
+            self.switch_to_facet('run_test')
+            self.wait_for_request(n=2)
+            self.button_click('run_test')
+            self.assert_dialog('message_dialog')
 
-        self.switch_to_facet('run_test')
-        self.button_click('run_test')
-        self.assert_dialog('message_dialog')
+        __hbac_ui_click_on_run_test(self)
         self.click_on_link('Target host')
         self.assert_facet('hbactest', 'targethost')
 
-        self.switch_to_facet('run_test')
-        self.button_click('run_test')
-        self.assert_dialog('message_dialog')
+        __hbac_ui_click_on_run_test(self)
         self.click_on_link('Service')
         self.assert_facet('hbactest', 'service')
