@@ -182,49 +182,6 @@ ipa_class_members = {
         'validatedns',
         'normalizedns',
     ],
-    'ipatests.test_integration.base.IntegrationTest': [
-        {'domain': [
-            {'name': dir(str)},
-        ]},
-        {'master': [
-            {'config': [
-                {'dirman_dn': dir(str)},
-                {'dirman_password': dir(str)},
-                {'admin_password': dir(str)},
-                {'admin_name': dir(str)},
-                {'dns_forwarder': dir(str)},
-                {'test_dir': dir(str)},
-                {'ad_admin_name': dir(str)},
-                {'ad_admin_password': dir(str)},
-                {'domain_level': dir(str)},
-                {'fips_mode': dir(bool)},
-            ]},
-            {'domain': [
-                {'basedn': dir(str)},
-                {'realm': dir(str)},
-                {'name': dir(str)},
-            ]},
-            {'external_hostname': dir(str)},
-            {'hostname': dir(str)},
-            'ip',
-            'collect_log',
-            {'run_command': [
-                {'stdout_text': dir(str)},
-                {'stderr_text': dir(str)},
-                'returncode',
-            ]},
-            {'transport': ['put_file', 'file_exists']},
-            'put_file_contents',
-            'get_file_contents',
-            'ldap_connect',
-        ]},
-        'replicas',
-        'clients',
-        'ad_domains',
-        {'ads': dir(list)},
-        {'ad_subdomains': dir(list)},
-        {'ad_treedomains': dir(list)},
-    ]
 }
 
 
@@ -239,8 +196,8 @@ MANAGER.register_transform(scoped_nodes.ClassDef, fix_ipa_classes)
 
 def ipaplatform_constants_transform():
     return AstroidBuilder(MANAGER).string_build(textwrap.dedent('''
-    from ipaplatform.base.constants import constants
-    __all__ = ('constants',)
+    from ipaplatform.base.constants import constants, User, Group
+    __all__ = ('constants', 'User', 'Group')
     '''))
 
 
@@ -434,10 +391,7 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
 
     api.env.api_version = ''
     api.env.bin = ''  # object
-    api.env.ca_agent_install_port = None
     api.env.ca_agent_port = 0
-    api.env.ca_ee_install_port = None
-    api.env.ca_ee_port = 0
     api.env.ca_host = ''
     api.env.ca_install_port = None
     api.env.ca_port = 0
@@ -452,6 +406,7 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     api.env.container_automount = DN()
     api.env.container_ca = DN()
     api.env.container_ca_renewal = DN()
+    api.env.container_subids = DN()
     api.env.container_caacl = DN()
     api.env.container_certmap = DN()
     api.env.container_certmaprules = DN()
@@ -464,12 +419,14 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     api.env.container_dna_posix_ids = DN()
     api.env.container_dns = DN()
     api.env.container_dnsservers = DN()
+    api.env.container_passkey = DN()
     api.env.container_group = DN()
     api.env.container_hbac = DN()
     api.env.container_hbacservice = DN()
     api.env.container_hbacservicegroup = DN()
     api.env.container_host = DN()
     api.env.container_hostgroup = DN()
+    api.env.container_idp = DN()
     api.env.container_locations = DN()
     api.env.container_masters = DN()
     api.env.container_netgroup = DN()
@@ -516,10 +473,6 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     api.env.interactive = True
     api.env.ipalib = ''  # object
     api.env.kinit_lifetime = None
-    api.env.lite_pem = ''
-    api.env.lite_profiler = ''
-    api.env.lite_host = ''
-    api.env.lite_port = 0
     api.env.log = ''  # object
     api.env.logdir = ''  # object
     api.env.mode = ''
@@ -546,6 +499,33 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     api.env.version = ''
     api.env.wait_for_dns = 0
     api.env.webui_prod = True
+
+    # defined in ipaclient/install/ipa_epn.py
+    api.env.smtp_server = ""
+    api.env.smtp_port = 0
+    api.env.smtp_user = None
+    api.env.smtp_password = None
+    api.env.smtp_client_cert = None
+    api.env.smtp_client_key = None
+    api.env.smtp_client_key_pass = None
+    api.env.smtp_timeout = 0
+    api.env.smtp_security = ""
+    api.env.smtp_admin = ""
+    api.env.smtp_delay = None
+    api.env.mail_from = None
+    api.env.mail_from_name = None
+    api.env.notify_ttls = ""
+    api.env.msg_charset = ""
+    api.env.msg_subtype = ""
+    api.env.msg_subject = ""
+
+    # defined in contrib/lite-server.py
+    api.env.lite_pem = ''
+    api.env.lite_profiler = ''
+    api.env.lite_host = ''
+    api.env.lite_port = 0
+    api.env.lite_tracemalloc = False
+
     """
 ))
 
@@ -578,3 +558,41 @@ AstroidBuilder(MANAGER).string_build(textwrap.dedent(
     dns.rdatatype.URI = 0
     """
 ))
+
+AstroidBuilder(MANAGER).string_build(
+    textwrap.dedent(
+        """\
+    from ipatests.test_integration.base import IntegrationTest
+    from ipatests.pytest_ipa.integration.host import Host, WinHost
+    from ipatests.pytest_ipa.integration.config import Config, Domain
+
+
+    class PylintIPAHosts:
+        def __getitem__(self, key):
+            return Host()
+
+
+    class PylintWinHosts:
+        def __getitem__(self, key):
+            return WinHost()
+
+
+    class PylintADDomains:
+        def __getitem__(self, key):
+            return Domain()
+
+
+    Host.config = Config()
+    Host.domain = Domain()
+
+    IntegrationTest.domain = Domain()
+    IntegrationTest.master = Host()
+    IntegrationTest.replicas = PylintIPAHosts()
+    IntegrationTest.clients = PylintIPAHosts()
+    IntegrationTest.ads = PylintWinHosts()
+    IntegrationTest.ad_treedomains = PylintWinHosts()
+    IntegrationTest.ad_subdomains = PylintWinHosts()
+    IntegrationTest.ad_domains = PylintADDomains()
+    """
+    )
+)
